#!/usr/bin/env ruby
# -*- coding: utf-8 -*-

module SidfmCvesHelper
  # サマリー表のチェックボックス
  def create_summary_cve_chkbox(cve_id, checked)
    content = check_box_tag(
      nil,
      cve_id,
      checked.include?(cve_id),
      :class => 'cveSelect'
    )
  end

  # サマリー表のCVE番号
  def create_summary_cve_id(cve_id)
    content = link_to(
      "#{cve_id}",
      "https://cve.mitre.org/cgi-bin/cvename.cgi?name=#{cve_id}'",
      :title => '別ウィンドウが開きます',
      :target => 'cve',
      :class => 'text-left text-nowrap'
    )
  end

  # サマリー表のCVSS
  def create_summary_cve_cvss(html_ids, cvss_score, cvss_v2_vector_texts, cvss_v3_vector_texts)
    cvss_label = SidfmdIssueCve.labelling(cvss_score).to_s
    cvss_vector_v3_items = cvss_v3_vector_texts.map{|vector_text|
      "<div>#{vector_text}</div>"
    }
    cvss_vector_v2_items = cvss_v2_vector_texts.map{|vector_text|
      "<div>#{vector_text}</div>"
    }
    cvss_vector_html = ''
    if cvss_vector_v3_items.any? then
      cvss_vector_html += %|<div class="summary-cvss-vs-title">CVSS V3</div>#{cvss_vector_v3_items.join}|
    end
    if cvss_vector_v2_items.any? then
      cvss_vector_html += %|<div class="summary-cvss-vs-title">CVSS V2</div>#{cvss_vector_v2_items.join}|
    end
    
    if cvss_vector_html.length == 0 then
      cvss_vector_html = '未登録'
    end

    data = {
      :toggle => 'tooltip',
      :title => cvss_vector_html,
      :placement => 'right',
      :boundary => 'window',
      :html => true
    }

    content = content_tag(
      :span,
      :class => "bgc_cvss_#{SidfmdIssueCve.labelling(cvss_score)} d-block mx-auto cvss-btn text-white b_radius cursor-default",
      :data => data
    ) do
      if cvss_label == 'notreg' then
        if html_ids.find{|html_id| html_id < 0 } then
          concat(
            content_tag(:span, 'n/a', :class => 'text-gray-999')
          )
        else
          concat(content_tag(:span, '---'))
        end
      else
        concat(content_tag(:span, cvss(cvss_score)))
      end
    end

    #if html_id < 0 then
    #  content = content.concat(create_summary_vul_win_cvss_info)
    #end
    content
  end

  # サマリー表の脆弱性
  def create_summary_cve_vuls(display_vul, vuls_count, cve_id)
    detail_link = -> (html_id, title, short_description, cls = nil){
      title = "[#{html_id >= 0 ? html_id : -html_id}]#{SidfmdVulView.display_title(title)}"
      link_to(
        title,
        url_for(:controller => :sidfm_vulnerability, :action => :index, :id => html_id),
        :data => {
          :toggle => 'tooltip',
          :title => %|<div>#{html_escape(title)}</div>#{(short_description && short_description.size > 0) ? %|<div class="vul-tooltip-short-description-area">#{html_escape(short_description)}</div>| : ""}|,
          :placement => 'right',
          :boundary => 'window',
          :html => true
        },
        :class => cls
      )
    }

    content = '---'
    if display_vul then
      if vuls_count == 1 then
        content = content_tag(:div, :class => 'text-left') do
          concat(
            detail_link.(
              display_vul[:html_id],
              display_vul[:title],
              display_vul[:short_description],
              "text-ellipsis summary-vul-title-width d-block"
            )
          )
        end
      elsif vuls_count > 1 then
        content = content_tag(:div, :class => 'text-left d-flex align-items-center') do
          concat(
            content_tag(:div, :class => 'mr-2') do
              detail_link.(
                display_vul[:html_id],
                display_vul[:title],
                display_vul[:short_description],
                "text-ellipsis summary-vul-title-width d-block"
              )
            end
          )
          .concat(
            create_summary_items_balloon(
              [display_vul],
              vuls_count - 1,
              '他脆弱性',
              {
                :button_class => 'summary-vul-title-width show-cve-vuls',
                :button_inner_text_style => 'max-width: 32rem; overflow: hidden; white-space: nowrap; text-overflow: ellipsis; margin-right: 2px;',
                :balloon_menu_style => 'max-width: 25rem;',
                :button_data => { :cveid => cve_id, :excepthtmlid => display_vul[:html_id] }
              }
            )#{|vul|
            #  detail_link.(
            #    display_vul[:html_id],
            #    display_vul[:title],
            #    display_vul[:short_description],
            #    "list-group-item text-truncate"
            #  )
            #}
          )
        end
      end
    end
    content
  end

  # サマリー表のホスト
  def create_summary_cve_hosts(display_host, hosts_count, cve_id)
    detail_link = -> (sidfmd_host_id, hostname, ext_name, display_name, cls = nil){
      link_to(
        display_name,
        url_for(:controller => :sidfm_host, :action => :index, :id => sidfmd_host_id),
        :data => {
          :toggle => 'tooltip',
          :title => "ホスト名: #{hostname}<br/>表示名: #{ext_name ? ext_name : '(未設定)'}",
          :placement => 'right',
          :boundary => 'window',
          :html => true
        },
        :class => cls
      )
    }

    content = '---'
    if display_host then
      if hosts_count == 1 then
        content = content_tag(:div, :class => 'text-left') do
          concat(
            detail_link.(
              display_host[:sidfmd_host_id],
              display_host[:hostname],
              display_host[:ext_name],
              display_host[:display_name],
              "g-width-12em text-ellipsis d-block"
            )
          )
        end
      elsif hosts_count > 1 then
        content = content_tag(:div, :class => 'text-left') do
          concat(
            create_summary_items_balloon(
              [display_host],
              hosts_count,
              display_host[:display_name],
              { :button_class => 'show-cve-hosts', :button_data => { :cveid => cve_id } }
            )#{|host|
            #  detail_link.(
            #    display_host[:sidfmd_host_id],
            #    display_host[:hostname],
            #    display_host[:ext_name],
            #    display_host[:display_name],
            #    "list-group-item text-truncate g-max-width-16em"
            #  )
            #}
          )
        end
      end
    end
    content
  end

  # サマリー表のSIDfmID
  #def create_summary_cve_sidfm_ids(html_ids)
  #  detail_link = -> (html_id, cls = nil){
  #    link_to("#{html_id}", url_for(:controller => :sidfm_vulnerability, :action => :index, :id => html_id), :class => cls)
  #  }
  #  content = '---'
  #  if html_ids.size == 1 then
  #    html_id = html_ids.first
  #    content = content_tag(:div, :class => 'text-left') do
  #      concat(detail_link.(html_id))
  #    end
  #  elsif html_ids.size > 1 then
  #    content = content_tag(:div, :class => 'text-left') do
  #      concat(
  #        create_summary_items_balloon(html_ids, "#{html_ids.first}"){|html_id|
  #          detail_link.(html_id, "list-group-item text-truncate")
  #        }
  #      )
  #    end
  #  end
  #  content
  #end

end
