#!/usr/bin/env ruby
# -*- coding: utf-8 -*-

class CreateSidfmQueues < ActiveRecord::Migration
  def change

    # 各Agentからの情報取得結果を保存する。
    # Redmineのあるサーバ上で脆弱性照合等の処理を行うために必要な情報を保持する。
    # FIXME: expireが必要？
    create_table :sidfm_queues do |t|
      t.references :sidfm_host, index: true

      # 情報取得時のsidfm_host.pkg_product_idをコピー
      # 変更される可能性があるため
      t.string :pkg_product_id

      # 処理（脆弱性の照合とissueの登録、更新）終了ならtrue
      t.boolean :is_done, default: false, null: false

      # OS／ディストリビューションを示すバナー文字列
      t.text :banner

      # 取得時に何らかのエラーが発生して取得に失敗した場合、
      # is_errにtrueを設定してその原因をerr_dataに出力する。
      # err_dataはJSON形式とする。
      t.boolean :is_err, default: false, null: false
      t.text :err_data

      # 取得時に何らかの問題が発生したが取得は出来ている場合、
      # is_warnにtrueを設定してその内容をwarn_dataに出力する。
      # warn_dataはJSON形式とする。
      t.boolean :is_warn, default: false, null: false
      t.text :warn_data

      t.integer :lock_version, default: 0, null: false
      t.timestamps
    end

    # 取得したパッケージの情報を保存する
    # パッケージ一覧取得のコマンド出力結果で、パッケージ名とバージョン
    # が分離されている場合はpkgname/pkgver、分離されていない場合は
    # pkgnameのみを使用する。
    # 今のところ、以下のように使用する予定
    #   rpm: pkgname
    #   deb: pkgname, pkgver
    create_table :sidfm_queue_pkgs do |t|
      t.references :sidfm_host, index: true

      # パッケージ名称とバージョン
      # rpmならpkgnameのみ、dpkgならpkgname,pkgver等、
      # パッケージシステム毎に使い方が変わる可能性がある
      t.text :pkgname
      t.text :pkgver

      t.integer :lock_version, default: 0, null: false
      t.timestamps
    end

    # 自動チェック対象のパッケージ外アプリケーションに関する情報を
    # 保持
    create_table :sidfm_queue_apps do |t|
      t.references :sidfm_queue, index: true

      # SIDfmでの対象アプリID
      t.string :product_id, null: false

      # 取得したバージョン情報
      t.string :ver_info, null: false

      # 情報取得に利用したファイルのパス名（Evidenceとして保持）
      t.string :path, null: false

      t.integer :lock_version, default: 0, null: false
      t.timestamps
    end

    # ゴミが入っていたため削除
    change_table :sidfm_hosts do |t|
      t.remove :index_id
      t.remove :true_id
      t.remove :project_id
      t.references :project_id, index: true
    end

  end
end
