#!/usr/bin/env ruby
# -*- coding: utf-8 -*-

module TestFiltersData
  def get_data
    #各型で、valuesのあるデータとないデータの一覧
    #フィルタのデータであり得えて、確認が必要なデータ形式の全パターン
    #sidfm_controller_support.rb#establish_filters_consistencyメソッドのテスト用データ

    #sidfm_hosts_controller.rb 等のinit_filter_keysメソッドで作成されるFILTER_KEYSの値(整合性を取るためのデータ)をテストデータとして生成したもの。
    #このデータには、(現フィルタにはないデータ形式のものも含めた)テストが必要な全形式のデータを入れています。
    #キーを型名またはデータ形式名にしています。
    filters_data = {
      :null => { :values => nil, :default => nil },
      :null_with_values => { :values => [ nil ], :default => nil },
      :null_with_type_source => { :values => [ nil ], :default => nil, :type_source => nil },
      :string => { :values => nil, :default => '' },
      :string_with_values => { :values => ['1', '2'], :default => '' },
      :string_with_type_source => { :values => ['1', '2'], :default => '', :type_source => '1' },
      :int => { :values => nil, :default => 1 },
      :int_with_values => { :values => [1,2,3], :default => 1 },
      :int_with_type_source => { :values => [1,2,3], :default => 1, :type_source => 1 },
      :float => { :values => nil, :default => 1.1 },
      :float_with_values => { :values => [1.1,2.1,3.1], :default => 1.1 },
      :float_with_type_source => { :values => nil, :default => 1.1, :type_source => 0.0 },
      :true => { :values => nil, :default => true }, #rubyだと異なるclassだが、型チェックでは真偽は同じ型として扱う
      :true_with_values => { :values => [true, false], :default => true },
      :true_with_type_source => { :values => nil, :default => true, :type_source => true },
      :false => { :values => nil, :default => false },
      :false_with_values => { :values => [true, false], :default => false },
      :false_with_type_source => { :values => [true, false], :default => true, :type_source => false },
      :array => { :values => nil, :default => [] },
      :array_with_values => { :values => [[1,2], [1]], :default => [1] },
      :array_with_values2 => { :values => { 1 => 1, 2 => 2 }, :default => [1] },
      :array_with_type_source_string => { :values => [['test'], ['test2']], :default => [], :type_source => [''] },
      :array_with_type_source_int => { :values => nil, :default => [], :type_source => [0] },
      :array_with_type_source_float => { :values => nil, :default => [], :type_source => [1.1] },
      :array_with_type_source_true => { :values => nil, :default => [], :type_source => [true] },
      :array_with_type_source_false => { :values => nil, :default => [], :type_source => [false] },
      :array_with_type_source_array => { :values => nil, :default => [], :type_source => [[]] },
      :array_with_type_source_hash => { :values => nil, :default => [], :type_source => [{:a => 1}] },
      :array_with_type_source_null => { :values => nil, :default => [], :type_source => [nil] },
      :null_array => { :values => nil, :default => [nil, nil] },
      :null_array_with_values => { :values => [[nil, nil], [nil, nil, nil]], :default => [nil, nil] },
      :string_array => { :values => nil, :default => ['test'] },
      :string_array_with_values => { :values => [['test'], ['test', 'test2']], :default => ['test'] },
      :int_array => { :values => nil, :default => [1] },
      :int_array_with_values => { :values => [[1], [1,2]], :default => [1] },
      :float_array => { :values => nil, :default => [1.1] },
      :float_array_with_values => { :values => [[1.1], [1.1,2.2]], :default => [1.1] },
      :bool_array => { :values => nil, :default => [true] },
      :bool_array_with_values => { :values => [[false], [true, false]], :default => [false] },
      :hash_array => { :values => nil, :default => [ {:a => 1} ] },
      :hash_array_with_values => { :values => [ [ {:a => 1} ], [ {:a => 2} ] ], :default => [ {:a => 1} ] },
      :array_empty_array => { :values => nil, :default => [[]] },
      :array_array => { :values => nil, :default => [[1]] },
      :array_array_with_values => { :values => [[[1]], [[2],[3,4]]], :default => [[1]] },
      :array_array_with_type_source_string => { :values => nil, :default => [[]], :type_source => [['']] },
      :array_array_with_type_source_int => { :values => [[[1]],[[2,3]]], :default => [[]], :type_source => [[0]] },
      :array_array_with_type_source_float => { :values => nil, :default => [[]], :type_source => [[1.1]] },
      :array_array_with_type_source_true => { :values => nil, :default => [[]], :type_source => [[true]] },
      :array_array_with_type_source_false => { :values => nil, :default => [[]], :type_source => [[false]] },
      :array_array_with_type_source_array => { :values => nil, :default => [[]], :type_source => [[[]]] },
      :array_array_with_type_source_hash => { :values => nil, :default => [[]], :type_source => [[{:a => 1}]] },
      :array_array_with_type_source_null => { :values => nil, :default => [[]], :type_source => [[nil]] },
      :hash => { :values => nil, :default => {} },
      :hash_with_values => { :values => [{}, {:a => 1}], :default => {} },
      :hash_with_type_source_string => { :values => nil, :default => {:a => '1'}, :type_source => { :a => ''} },
      :hash_with_type_source_int => { :values => nil, :default => {:a => 3}, :type_source => { :a => 1 } },
      :hash_with_type_source_float => { :values => nil, :default => {:a => 2.2}, :type_source => { :a => 1.1 } },
      :hash_with_type_source_true => { :values => nil, :default => {:a => true}, :type_source => { :a => true } },
      :hash_with_type_source_false => { :values => nil, :default => {:a => false}, :type_source => { :a => false } },
      :hash_with_type_source_array => { :values => nil, :default => {:a => []}, :type_source => { :a => [] } },
      :hash_with_type_source_hash => { :values => nil, :default => {:a => {}}, :type_source => { :a => {} } },
      :hash_with_type_source_null => { :values => nil, :default => {:a => nil}, :type_source => { :a => nil } },
      :hash_with_type_source_array_hash => { :values => nil, :default => {:a => [{}]}, :type_source => { :a => [{}] } },
      :hash_with_type_source_hash_hash => { :values => nil, :default => {:a => { :aa => {:a => 'sample'}}}, :type_source => { :a => { :aa => {:a => ''} } } },
      :hash_with_type_source_array_hash_array => {
        :values => nil,
        :default => { :a => [ { :bb => [3] } ] },
        :type_source => { :a => [ {:bb => [0] } ] }
      },
      :null_hash => {
        :values => nil,
        :default => { :a => nil, :b => 1 }
      },
      :null_hash_with_values => {
        :values => [{ :a => nil, :b => 1 }, { :b => nil, :a => nil }],
        :default => { :a => nil, :b => 1 }
      },
      :string_hash => {
        :values => nil,
        :default => { :a => 'test' }
      },
      :string_hash_with_values => {
        :values => [{ :a => 'test' }, { :a => 'test2' }],
        :default => { :a => 'test' }
      },
      :int_hash => {
        :values => nil,
        :default => { :a => 1 }
      },
      :int_hash_with_values => {
        :values => [{ :a => 1, :b => 2 }, { :a => 1, :b => 3 }, { :b => 2, :a => 5 }],
        :default => { :a => 1, :b => 2 }
      },
      :float_hash => {
        :values => nil,
        :default => { :a => 1.1 }
      },
      :float_hash_with_values => {
        :values => [{ :a => 1.3 }, { :a => 1.1 }, { :a => 2.2 }],
        :default => { :a => 1.1 }
      },
      :bool_hash => {
        :values => nil,
        :default => { :b => false }
      },
      :bool_hash_with_values => {
        :values => [{ :a => true, :b => false }, { :a => true, :b => true }, { :b => false, :a => false }],
        :default => { :a => true, :b => false }
      },
      :array_hash => {
        :values => nil,
        :default => { :a => [] }
      },
      :array_hash_with_values => {
        :values => [ { :a => [1] }, { :a => [] } ],
        :default => { :a => [] }
      },
      :array_null_hash => {
        :values => nil,
        :default => { :a => [nil], :b => [nil, nil] }
      },
      :array_null_hash_with_values => {
        :values => [{ :a => [nil], :b => [nil, nil] }, { :a => [nil], :b => [nil] }],
        :default => { :a => [nil], :b => [nil, nil] }
      },
      :array_int_hash => {
        :values => nil,
        :default => { :a => [1] }
      },
      :array_int_hash_with_values => {
        :values => [ { :a => [1] }, { :a => [1, 2] } ],
        :default => { :a => [1] }
      },
      :array_float_hash => {
        :values => nil,
        :default => { :a => [1.1] }
      },
      :array_float_hash_with_values => {
        :values => [ { :a => [1.1] }, { :a => [1.1, 2.2] } ],
        :default => { :a => [1.1] }
      },
      :array_string_hash => {
        :values => nil,
        :default => { :a => ['test'] }
      },
      :array_string_hash_with_values => {
        :values => [ { :a => ['test'] }, { :a => ['test1'] }, { :a => ['test', 'test2'] } ],
        :default => { :a => ['test'] }
      },
      :array_bool_hash => {
        :values => nil, 
        :default => { :a => [true] }
      },
      :array_bool_hash_with_values => {
        :values => [ { :a => [false] }, { :a => [false, true] } ],
        :default => { :a => [false] }
      },
      :array_array_hash => {
        :values => nil,
        :default => { :a => [['test']] }
      },
      :array_array_hash_with_values => {
        :values => [ { :a => [['test']] }, { :a => [['test', 'test2']] } ],
        :default => { :a => [['test']] }
      },
      :array_hash_hash => {
        :values => nil, 
        :default => { :a => [ { :aa => 'test' } ] }
      },
      :array_hash_hash_with_values => {
        :values => [ { :a => [ { :aa => 'test' } ] }, { :a => [ { :aa => 'test2' } ] } ],
        :default => { :a => [ { :aa => 'test' } ] }
      },
      :nested_null_hash => { #以降はネストが深いhash。これ以上の深さはメソッドの実装上意味がない(+切りがない)ので、この深さまで。
        :values => nil,
        :default => {
          :a => { :aa => nil },
        }
      },
      :nested_null_hash_with_values => {
        :values => [
          { :a => { :aa => nil } },
          { :a => { :aa => 1 } }
        ],
        :default => {
          :a => { :aa => nil },
        }
      },
      :nested_string_hash => {
        :values => nil,
        :default => {
          :a => { :aa => 'test' },
        }
      },
      :nested_string_hash_with_values => {
        :values => [ {:a => { :aa => 'test' }}, {:a => { :aa => 'test2'}} ],
        :default => {
          :a => { :aa => 'test' },
        }
      },
      :nested_int_hash => {
        :values => nil,
        :default => {
          :a => { :aa => 1 },
          :b => { :bb => 2 }
        }
      },
      :nested_int_hash_with_values => {
        :values => [ {:a => { :aa => 1, :bb => 2 }}, {:a => { :aa => 2, :bb => 5 }} ],
        :default => {
          :a => { :aa => 1, :bb => 2 },
        }
      },
      :nested_float_hash => {
        :values => nil,
        :default => {
          :a => { :aa => 1.1 },
        }
      },
      :nested_float_hash_with_values => {
        :values => [ {:a => { :aa => 1.1 }, :b => { :bb => 1.1 }}, {:a => { :aa => 1.5 }, :b => { :bb => 1.5 }} ],
        :default => {
          :a => { :aa => 1.1 },
          :b => { :bb => 1.1 },
        }
      },
      :nested_bool_hash => {
        :values => nil,
        :default => {
          :a => { :aa => true },
        }
      },
      :nested_bool_hash_with_values => {
        :values => [ {:a => { :aa => false }}, {:a => { :aa => nil }} ],
        :default => {
          :a => { :aa => false },
        }
      },
      :nested_array_hash => {
        :values => nil,
        :default => {
          :a => { :aa => [1] },
        }
      },
      :nested_array_hash_with_values => {
        :values => [ {:a => { :aa => [1] }, :b => { :bb => [1, 2] }}, {:a => { :aa => [2] }, :b => { :bb => [1] }}],
        :default => {
          :a => { :aa => [1] },
          :b => { :bb => [1, 2] }
        }
      },
    }
    { :original_data => filters_data, :default_filters => filters_data.map{|k, v| [k, v[:default]]}.to_h }
  end
end
