require File.expand_path('../../../test_helper', __FILE__)
require_relative('../../../lib/sidfm_controller_support')
require_relative('../../test_data/filters/test_filters_data')

class FiltersConsistencyTest < ActiveSupport::TestCase
  include TestFiltersData, SidfmControllerSupport
  def setup
    #フィルタの整合性ををとる元データのテストデータ
    #各型とvaluesがあるものとないものをテストする
    data = get_data
    @original_data = data[:original_data] #フィルタの整合性をとる元データ
    @default_filters = data[:default_filters] #(検索していない状態の)デフォルトのフィルタデータ
  end

  test "デフォルトのフィルタでは、メソッドを呼ぶ前のデータと後のデータが変わらないこと2.7.0" do
    filterd_filters = establish_filters_consistency(@default_filters, @original_data)
    assert filterd_filters == @default_filters
  end

  test "フィルタが空の場合は、デフォルトのフィルタが設定されること" do
    filterd_filters = establish_filters_consistency({}, @original_data)
    assert filterd_filters == @default_filters
    filterd_filters = establish_filters_consistency({:string => 'test'}, @original_data)
    assert_not filterd_filters == @default_filters
    filterd_filters[:string] = @default_filters[:string]
    assert filterd_filters == @default_filters
  end

  test "存在しないフィルタのキーは削除されること 2.7.0" do
    @default_filters[:test] = 'test'
    filterd_filters = establish_filters_consistency(@default_filters, @original_data)
    assert_not filterd_filters.has_key?(:test)
    @default_filters.delete(:test)
    assert filterd_filters == @default_filters
  end

  #NULLのデータのテスト
  test "型が異なる場合は、デフォルト値になること(NULLと文字列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:null] = 'test'
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null] == @default_filters[:null]
  end

  test "型が異なる場合は、デフォルト値になること(NULLとtrue)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:null] = true
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null] == @default_filters[:null]
  end

  test "型が異なる場合は、デフォルト値になること(NULLとfalse)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:null] = false
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null] == @default_filters[:null]
  end

  test "型が異なる場合は、デフォルト値になること(NULLと数値)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:null] = 1
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null] == @default_filters[:null]
  end

  test "型が異なる場合は、デフォルト値になること(NULLと小数)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:null] = 1.1
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null] == @default_filters[:null]
  end

  test "型が異なる場合は、デフォルト値になること(NULLと配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:null] = ['1']
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null] == @default_filters[:null]
  end

  test "型が異なる場合は、デフォルト値になること(NULLとハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:null] = { :test => nil }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null] == @default_filters[:null]
  end

  #「型が同じ場合は、指定した値が設定されること(NULL)」のテストはnilをnilにするテストが無意味なので無し

  #valuesがあるデータのテスト
  test "valuesに含まれない値が指定されている場合は、デフォルト値になること(NULL)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:null_with_values] = 2
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:null_with_values] == filters[:null_with_values]
    assert filterd_filters[:null_with_values] == @default_filters[:null_with_values]
  end

  #「valuesに含まれる値が指定されている場合は、指定した値が設定されること(NULL)」のテストはnilをnilにするテストが無意味なので無し

  #文字列のデータのテスト
  test "型が異なる場合は、デフォルト値になること(文字列とNULL)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:string] = nil
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:string] == @default_filters[:string]
  end

  test "型が異なる場合は、デフォルト値になること(文字列とtrue)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:string] = true
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:string] == @default_filters[:string]
  end

  test "型が異なる場合は、デフォルト値になること(文字列とfalse)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:string] = false
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:string] == @default_filters[:string]
  end

  test "型が異なる場合は、デフォルト値になること(文字列と数値)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:string] = 1
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:string] == @default_filters[:string]
  end

  test "型が異なる場合は、デフォルト値になること(文字列と小数)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:string] = 1.2
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:string] == @default_filters[:string]
  end

  test "型が異なる場合は、デフォルト値になること(文字列と配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:string] = ['1']
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:string] == @default_filters[:string]
  end

  test "型が異なる場合は、デフォルト値になること(文字列とハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:string] = { :test => 'test' }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:string] == @default_filters[:string]
  end

  test "型が同じ場合は、指定した値が設定されること(文字列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:string] = 'test'
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:string] == filters[:string]
  end

  #valuesがあるデータのテスト
  test "valuesに含まれない値が指定されている場合は、デフォルト値になること(文字列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:string_with_values] = '3'
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:string_with_values] == filters[:string_with_values]
    assert filterd_filters[:string_with_values] == @default_filters[:string_with_values]
  end

  test "valuesに含まれる値が指定されている場合は、指定した値が設定されること(文字列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:string_with_values] = '2'
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:string_with_values] == filters[:string_with_values]
    assert_not filterd_filters[:string_with_values] == @default_filters[:string_with_values]
  end

  #数値のデータのテスト
  test "型が異なる場合は、デフォルト値になること(数値とNULL)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:int] = nil
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:int] == @default_filters[:int]
  end

  test "型が異なる場合は、デフォルト値になること(数値とtrue)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:int] = true
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:int] == @default_filters[:int]
  end

  test "型が異なる場合は、デフォルト値になること(数値とfalse)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:int] = false
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:int] == @default_filters[:int]
  end

  test "型が異なる場合は、デフォルト値になること(数値と文字列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:int] = '1'
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:int] == @default_filters[:int]
  end

  test "型が異なる場合は、デフォルト値になること(数値と小数)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:int] = 1.1
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:int] == @default_filters[:int]
  end

  test "型が異なる場合は、デフォルト値になること(数値と配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:int] = [1]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:int] == @default_filters[:int]
  end

  test "型が異なる場合は、デフォルト値になること(数値とハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:int] = { :test => 1 }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:int] == @default_filters[:int]
  end

  test "型が同じ場合は、指定した値が設定されること(数値)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:int] = 3
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:int] == filters[:int]
  end

  #valuesがあるデータのテスト
  test "valuesに含まれない値が指定されている場合は、デフォルト値になること(数値)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:int_with_values] = 5
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:int_with_values] == filters[:int_with_values]
    assert filterd_filters[:int_with_values] == @default_filters[:int_with_values]
  end

  test "valuesに含まれる値が指定されている場合は、指定した値が設定されること(数値)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:int_with_values] = 3
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:int_with_values] == filters[:int_with_values]
    assert_not filterd_filters[:int_with_values] == @default_filters[:int_with_values]
  end

  #小数のデータのテスト
  test "型が異なる場合は、デフォルト値になること(小数とNULL)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:float] = nil
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:float] == @default_filters[:float]
  end

  test "型が異なる場合は、デフォルト値になること(小数とtrue)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:float] = true
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:float] == @default_filters[:float]
  end

  test "型が異なる場合は、デフォルト値になること(小数とfalse)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:float] = false
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:float] == @default_filters[:float]
  end

  test "型が異なる場合は、デフォルト値になること(小数と文字列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:float] = '1.1'
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:float] == @default_filters[:float]
  end

  test "型が異なる場合は、デフォルト値になること(小数と数値)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:float] = 1
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:float] == @default_filters[:float]
  end

  test "型が異なる場合は、デフォルト値になること(小数と配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:float] = [1.1, 2.2]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:float] == @default_filters[:float]
  end

  test "型が異なる場合は、デフォルト値になること(小数とハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:float] = { :test => 1.1, :test2 => 2.2 }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:float] == @default_filters[:float]
  end

  test "型が同じ場合は、指定した値が設定されること(小数)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:float] = 3.3
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:float] == filters[:float]
  end

  #valuesがあるデータのテスト
  test "valuesに含まれない値が指定されている場合は、デフォルト値になること(小数)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:float_with_values] = 3.2
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:float_with_values] == filters[:float_with_values]
    assert filterd_filters[:float_with_values] == @default_filters[:float_with_values]
  end

  test "valuesに含まれる値が指定されている場合は、指定した値が設定されること(小数)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:float_with_values] = 3.1
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:float_with_values] == filters[:float_with_values]
    assert_not filterd_filters[:float_with_values] == @default_filters[:float_with_values]
  end

  #真のデータのテスト rubyだと異なるclassだが、メソッドの型チェックでは真偽は同じ型として扱う
  test "型が異なる場合は、デフォルト値になること(trueとNULL)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:true] = nil
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:true] == @default_filters[:true]
  end

  test "型が異なる場合は、デフォルト値になること(trueと文字列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:true] = 'true'
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:true] == @default_filters[:true]
  end

  test "型が異なる場合は、デフォルト値になること(trueと数値)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:true] = 1
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:true] == @default_filters[:true]
  end

  test "型が異なる場合は、デフォルト値になること(trueと小数)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:true] = 1.1
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:true] == @default_filters[:true]
  end

  test "型が異なる場合は、デフォルト値になること(trueと配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:true] = [true]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:true] == @default_filters[:true]
  end

  test "型が異なる場合は、デフォルト値になること(trueとハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:true] = { :test => true }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:true] == @default_filters[:true]
  end

  test "型が同じ場合は、指定した値が設定されること(真と偽)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:true] = false
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:true] == filters[:true]
  end
  #valuesがあるデータのテストは、valuesがtrueかfalseのみなのでなし

  #偽のデータのテスト
  test "型が異なる場合は、デフォルト値になること(falseとNULL)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:false] = nil
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:false] == @default_filters[:false]
  end

  test "型が異なる場合は、デフォルト値になること(falseと文字列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:false] = 'false'
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:false] == @default_filters[:false]
  end

  test "型が異なる場合は、デフォルト値になること(falseと数値)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:false] = 1
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:false] == @default_filters[:false]
  end

  test "型が異なる場合は、デフォルト値になること(falseと小数)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:false] = 1.1
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:false] == @default_filters[:false]
  end

  test "型が異なる場合は、デフォルト値になること(falseと配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:false] = [false]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:false] == @default_filters[:false]
  end

  test "型が異なる場合は、デフォルト値になること(falseとハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:false] = { :test => false }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:false] == @default_filters[:false]
  end

  test "型が同じ場合は、指定した値が設定されること(偽と真)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:false] = true
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:false] == filters[:false]
  end

  #配列のデータのテスト
  test "型が異なる場合は、デフォルト値になること(配列とNULL)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array] = nil
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array] == @default_filters[:array]
  end

  test "型が異なる場合は、デフォルト値になること(配列とtrue)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array] = true
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array] == @default_filters[:array]
  end

  test "型が異なる場合は、デフォルト値になること(配列とfalse)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array] = false
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array] == @default_filters[:array]
  end

  test "型が異なる場合は、デフォルト値になること(配列と文字列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array] = 'test'
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array] == @default_filters[:array]
  end

  test "型が異なる場合は、デフォルト値になること(配列と数値)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array] = 1
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array] == @default_filters[:array]
  end

  test "型が異なる場合は、デフォルト値になること(配列と小数)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array] = 1.1
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array] == @default_filters[:array]
  end

  test "型が異なる場合は、デフォルト値になること(配列とハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array] = { :test => [] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array] == @default_filters[:array]
  end

  test "型が同じ場合は、指定した値が設定されること(配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array] = [1,2,3]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array] == filters[:array]
  end

  #valuesがあるデータのテスト
  test "valuesに含まれない値が指定されている場合は、デフォルト値になること(配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_with_values] = [1,2,3]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:array_with_values] == filters[:array_with_values]
    assert filterd_filters[:array_with_values] == @default_filters[:array_with_values]
  end

  test "valuesに含まれない値が指定されている場合は、その値は削除されること(配列)(valuesがhash)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_with_values2] = [1,2,3]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_with_values2] == [1,2]
    assert_not filterd_filters[:array_with_values2] == @default_filters[:array_with_values2]
    filters[:array_with_values2] = [3,5]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_with_values2] == []
    assert_not filterd_filters[:array_with_values2] == @default_filters[:array_with_values2]
  end

  test "valuesに含まれる値が指定されている場合は、指定した値が設定されること(配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_with_values] = [1,2]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_with_values] == filters[:array_with_values]
    assert_not filterd_filters[:array_with_values] == @default_filters[:array_with_values]
  end
 
  test "valuesに含まれる値が指定されている場合は、指定した値が設定されること(配列)(valuesがhash)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_with_values2] = [2]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_with_values2] == filters[:array_with_values2]
    assert_not filterd_filters[:array_with_values2] == @default_filters[:array_with_values2]
    filters[:array_with_values2] = [1,2]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_with_values2] == filters[:array_with_values2]
    assert_not filterd_filters[:array_with_values2] == @default_filters[:array_with_values2]
  end

  #配列で中身がNULLデータのテスト

  test "型が異なる場合は、デフォルト値になること(中身がNULLの配列と中身がtrueの配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:null_array] = [ true ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null_array] == @default_filters[:null_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身がNULLの配列と中身がfalseの配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:null_array] = [ false ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null_array] == @default_filters[:null_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身がNULLの配列と中身が文字列の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:null_array] = [ 'test' ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null_array] == @default_filters[:null_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身がNULLの配列と中身が数値の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:null_array] = [ 1 ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null_array] == @default_filters[:null_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身がNULLの配列と中身が小数の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:null_array] = [ 1.1 ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null_array] == @default_filters[:null_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身がNULLの配列と中身が配列の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:null_array] = [ [nil] ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null_array] == @default_filters[:null_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身がNULLの配列と中身がハッシュの配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:null_array] = [ { :test => [nil] } ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null_array] == @default_filters[:null_array]
  end

  test "型が同じ場合は、指定した値が設定されること(中身がNULLの配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:null_array] = [nil]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null_array] == filters[:null_array]
  end

  test "空配列は設定できること(中身がNULLの配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:null_array] = []
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null_array] == filters[:null_array]
  end

  #valuesがあるデータのテスト
  test "valuesに含まれない値が指定されている場合は、デフォルト値になること(中身がNULLの配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:null_array_with_values] = [nil]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:null_array_with_values] == filters[:null_array_with_values]
    assert filterd_filters[:null_array_with_values] == @default_filters[:null_array_with_values]
  end

  test "valuesに含まれる値が指定されている場合は、指定した値が設定されること(中身がNULLの配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:null_array_with_values] = [nil, nil, nil]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null_array_with_values] == filters[:null_array_with_values]
    assert_not filterd_filters[:null_array_with_values] == @default_filters[:null_array_with_values]
  end

  #配列で中身が文字列のデータのテスト
  test "型が異なる場合は、デフォルト値になること(中身が文字列の配列と中身がtrueの配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:string_array] = [ true ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:string_array] == @default_filters[:string_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身が文字列の配列と中身がfalseの配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:string_array] = [ false ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:string_array] == @default_filters[:string_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身が文字列の配列と中身がNULLの配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:string_array] = [ nil ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:string_array] == @default_filters[:string_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身が文字列の配列と中身が数値の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:string_array] = [ 1 ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:string_array] == @default_filters[:string_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身が文字列の配列と中身が小数の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:string_array] = [ 1.1 ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:string_array] == @default_filters[:string_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身が文字列の配列と中身が配列の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:string_array] = [ ['test'] ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:string_array] == @default_filters[:string_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身が文字列の配列と中身がハッシュの配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:string_array] = [ { :test => ['test'] } ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:string_array] == @default_filters[:string_array]
  end

  test "型が同じ場合は、指定した値が設定されること(中身が文字列の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:string_array] = ['pass']
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:string_array] == filters[:string_array]
  end

  test "空配列は設定できること(中身が文字列の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:string_array] = []
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:string_array] == filters[:string_array]
  end
  
  #valuesがあるデータのテスト
  test "valuesに含まれない値が指定されている場合は、デフォルト値になること(中身が文字列の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:string_array_with_values] = ['test3']
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:string_array_with_values] == filters[:string_array_with_values]
    assert filterd_filters[:string_array_with_values] == @default_filters[:string_array_with_values]
  end

  test "valuesに含まれる値が指定されている場合は、指定した値が設定されること(中身が文字列の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:string_array_with_values] = ['test', 'test2']
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:string_array_with_values] == filters[:string_array_with_values]
    assert_not filterd_filters[:string_array_with_values] == @default_filters[:string_array_with_values]
  end

  #配列で中身が数値のデータのテスト
  test "型が異なる場合は、デフォルト値になること(中身が数値の配列と中身がtrueの配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:int_array] = [ true ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:int_array] == @default_filters[:int_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身が数値の配列と中身がfalseの配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:int_array] = [ false ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:int_array] == @default_filters[:int_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身が数値の配列と中身がNULLの配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:int_array] = [ nil ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:int_array] == @default_filters[:int_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身が数値の配列と中身が文字列の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:int_array] = [ '1' ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:int_array] == @default_filters[:int_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身が数値の配列と中身が小数の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:int_array] = [ 1.1 ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:int_array] == @default_filters[:int_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身が数値の配列と中身が配列の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:int_array] = [ [1] ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:int_array] == @default_filters[:int_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身が数値の配列と中身がハッシュの配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:int_array] = [ { :test => [1] } ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:int_array] == @default_filters[:int_array]
  end

  test "型が同じ場合は、指定した値が設定されること(中身が数値の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:int_array] = [1,2,3]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:int_array] == filters[:int_array]
  end

  #valuesがあるデータのテスト
  test "valuesに含まれない値が指定されている場合は、デフォルト値になること(中身が数値の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:int_array_with_values] = [1,2,3]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:int_array_with_values] == filters[:int_array_with_values]
    assert filterd_filters[:int_array_with_values] == @default_filters[:int_array_with_values]
  end

  test "valuesに含まれる値が指定されている場合は、指定した値が設定されること(中身が数値の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:int_array_with_values] = [1,2]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:int_array_with_values] == filters[:int_array_with_values]
    assert_not filterd_filters[:int_array_with_values] == @default_filters[:int_array_with_values]
  end

  #配列で中身が小数のデータのテスト
  test "型が異なる場合は、デフォルト値になること(中身が小数の配列と中身がtrueの配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:float_array] = [ true ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:float_array] == @default_filters[:float_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身が小数の配列と中身がfalseの配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:float_array] = [ false ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:float_array] == @default_filters[:float_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身が小数の配列と中身がNULLの配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:float_array] = [ nil ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:float_array] == @default_filters[:float_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身が小数の配列と中身が数値の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:float_array] = [ 1 ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:float_array] == @default_filters[:float_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身が小数の配列と中身が文字列の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:float_array] = [ '1.1' ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:float_array] == @default_filters[:float_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身が小数の配列と中身が配列の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:float_array] = [ [1.1] ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:float_array] == @default_filters[:float_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身が小数の配列と中身がハッシュの配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:float_array] = [ { :test => [1.1] } ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:float_array] == @default_filters[:float_array]
  end

  test "型が同じ場合は、指定した値が設定されること(中身が小数の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:float_array] = [3.3]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:string_array] == filters[:string_array]
  end

  #valuesがあるデータのテスト
  test "valuesに含まれない値が指定されている場合は、デフォルト値になること(中身が小数の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:float_array_with_values] = [3.3, 1.1]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:float_array_with_values] == filters[:float_array_with_values]
    assert filterd_filters[:float_array_with_values] == @default_filters[:float_array_with_values]
  end

  test "valuesに含まれる値が指定されている場合は、指定した値が設定されること(中身が小数の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:float_array_with_values] = [1.1, 2.2]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:float_array_with_values] == filters[:float_array_with_values]
    assert_not filterd_filters[:float_array_with_values] == @default_filters[:float_array_with_values]
  end

  #配列で中身が真偽のデータのテスト
  test "型が異なる場合は、デフォルト値になること(中身が真偽の配列と中身が文字列の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:bool_array] = [ 'true' ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:bool_array] == @default_filters[:bool_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身が真偽の配列と中身がNULLの配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:bool_array] = [ nil ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:bool_array] == @default_filters[:bool_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身が真偽の配列と中身が数値の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:bool_array] = [ 1 ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:bool_array] == @default_filters[:bool_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身が真偽の配列と中身が小数の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:bool_array] = [ 1.1 ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:bool_array] == @default_filters[:bool_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身が真偽の配列と中身が配列の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:bool_array] = [ ['test'] ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:bool_array] == @default_filters[:bool_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身が真偽の配列と中身がハッシュの配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:bool_array] = [ { :test => [true] } ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:bool_array] == @default_filters[:bool_array]
  end

  test "型が同じ場合は、指定した値が設定されること(中身が真偽の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:bool_array] = [false]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:bool_array] == filters[:bool_array]
  end
  #valuesがあるデータのテスト
  test "valuesに含まれない値が指定されている場合は、デフォルト値になること(中身が真偽の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:bool_array_with_values] = [true]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:bool_array_with_values] == filters[:bool_array_with_values]
    assert filterd_filters[:bool_array_with_values] == @default_filters[:bool_array_with_values]
  end

  test "valuesに含まれる値が指定されている場合は、指定した値が設定されること(中身が真偽の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:bool_array_with_values] = [true, false]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:bool_array_with_values] == filters[:bool_array_with_values]
    assert_not filterd_filters[:bool_array_with_values] == @default_filters[:bool_array_with_values]
  end

  #配列で中身がハッシュのデータのテスト
  test "型が異なる場合は、デフォルト値になること(中身がハッシュの配列と中身がtrueの配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:hash_array] = [ true ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:hash_array] == @default_filters[:hash_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身がハッシュの配列と中身がfalseの配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:hash_array] = [ false ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:hash_array] == @default_filters[:hash_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身がハッシュの配列と中身がNULLの配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:hash_array] = [ nil ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:hash_array] == @default_filters[:hash_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身がハッシュの配列と中身が数値の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:hash_array] = [ 1 ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:hash_array] == @default_filters[:hash_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身がハッシュの配列と中身が小数の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:hash_array] = [ 1.1 ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:hash_array] == @default_filters[:hash_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身がハッシュの配列と中身が配列の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:hash_array] = [ [ {:test => 1} ] ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:hash_array] == @default_filters[:hash_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身がハッシュの配列と中身が文字列の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:hash_array] = [ 'test' ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:hash_array] == @default_filters[:hash_array]
  end

  test "型が同じ場合は、指定した値が設定されること(中身がハッシュの配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:hash_array] = [ { :a => 2 } ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:hash_array] == filters[:hash_array]
  end
  #valuesがあるデータのテスト
  test "valuesに含まれない値が指定されている場合は、デフォルト値になること(中身がハッシュの配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:hash_array_with_values] = [ {:a => 3} ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:hash_array_with_values] == filters[:hash_array_with_values]
    assert filterd_filters[:hash_array_with_values] == @default_filters[:hash_array_with_values]
  end

  test "valuesに含まれる値が指定されている場合は、指定した値が設定されること(中身がハッシュの配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:hash_array_with_values] = [ {:a => 2} ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:hash_array_with_values] == filters[:hash_array_with_values]
    assert_not filterd_filters[:hash_array_with_values] == @default_filters[:hash_array_with_values]
  end

  #配列で中身が配列のデータのテスト
  test "型が異なる場合は、デフォルト値になること(中身が配列の配列と中身がtrueの配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_array] = [ true ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array] == @default_filters[:array_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身が配列の配列と中身がfalseの配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_array] = [ false ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array] == @default_filters[:array_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身が配列の配列と中身がNULLの配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_array] = [ nil ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array] == @default_filters[:array_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身が配列の配列と中身が数値の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_array] = [ 1 ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array] == @default_filters[:array_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身が配列の配列と中身が小数の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_array] = [ 1.1 ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array] == @default_filters[:array_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身が配列の配列と中身が文字列の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_array] = [ 'test' ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array] == @default_filters[:array_array]
  end

  test "型が異なる場合は、デフォルト値になること(中身が配列の配列と中身がハッシュの配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_array] = [ { :test => [] } ]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array] == @default_filters[:array_array]
  end

  test "配列の中身の型が異なる場合は、デフォルト値になること(中身が配列の配列と中身がハッシュの配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_array] = [[nil]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array] == @default_filters[:array_array]
    filters = @default_filters.deep_dup
    filters[:array_array] = [[true]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array] == @default_filters[:array_array]
    filters = @default_filters.deep_dup
    filters[:array_array] = [[false]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array] == @default_filters[:array_array]
    filters = @default_filters.deep_dup
    filters[:array_array] = [['1']]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array] == @default_filters[:array_array]
    filters = @default_filters.deep_dup
    filters[:array_array] = [[1.1]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array] == @default_filters[:array_array]
    filters = @default_filters.deep_dup
    filters[:array_array] = [[[]]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array] == @default_filters[:array_array]
    filters[:array_array] = [[{}]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array] == @default_filters[:array_array]
  end

  test "元データの配列の中身がない場合は、指定した値が設定されること(中身が配列の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_empty_array] = [[nil]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_empty_array] == filters[:array_empty_array]
    filters[:array_empty_array] = [[true]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_empty_array] == filters[:array_empty_array]
    filters[:array_empty_array] = [[false]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_empty_array] == filters[:array_empty_array]
    filters[:array_empty_array] = [[1]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_empty_array] == filters[:array_empty_array]
    filters[:array_empty_array] = [[1.1]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_empty_array] == filters[:array_empty_array]
    filters[:array_empty_array] = [['test']]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_empty_array] == filters[:array_empty_array]
    filters[:array_empty_array] = [[{}]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_empty_array] == filters[:array_empty_array]
  end

  test "型が同じ場合は、指定した値が設定されること(中身が配列の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_array] = [[1,2,3], [1]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array] == filters[:array_array]
    filters[:array_array] = [[]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array] == filters[:array_array]
  end

  #valuesがあるデータのテスト
  test "valuesに含まれない値が指定されている場合は、デフォルト値になること(中身が配列の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_array_with_values] = [[1,2,3], [1]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:array_array_with_values] == filters[:array_array_with_values]
    assert filterd_filters[:array_array_with_values] == @default_filters[:array_array_with_values]
  end

  test "valuesに含まれる値が指定されている場合は、指定した値が設定されること(中身が配列の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_array_with_values] = [[2],[3,4]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array_with_values] == filters[:array_array_with_values]
    assert_not filterd_filters[:array_array_with_values] == @default_filters[:array_array_with_values]
  end
 
  #ハッシュのデータのテスト
  test "型が異なる場合は、デフォルト値になること(ハッシュとNULL)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:hash] = nil
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:hash] == @default_filters[:hash]
  end

  test "型が異なる場合は、デフォルト値になること(ハッシュとtrue)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:hash] = true
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:hash] == @default_filters[:hash]
  end

  test "型が異なる場合は、デフォルト値になること(ハッシュとfalse)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:hash] = false
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:hash] == @default_filters[:hash]
  end

  test "型が異なる場合は、デフォルト値になること(ハッシュと数値)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:hash] = 1
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:hash] == @default_filters[:hash]
  end

  test "型が異なる場合は、デフォルト値になること(ハッシュと小数)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:hash] = 1.2
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:hash] == @default_filters[:hash]
  end

  test "型が異なる場合は、デフォルト値になること(ハッシュと配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:hash] = ['1']
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:hash] == @default_filters[:hash]
  end

  test "型が異なる場合は、デフォルト値になること(ハッシュと文字列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:hash] = 'test'
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:hash] == @default_filters[:hash]
  end

  test "型が同じでも、キーの数が異なる場合はデフォルト値になること(ハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:hash] = { :test => 'test' }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:hash] == @default_filters[:hash]
  end

  #valuesがあるデータのテストは、キーの数が異なるとデフォルト値になるので不可(デフォルト値と同じにしないと常にfailする)

  #valueにNULLを含むハッシュのデータのテスト
  test "型が異なる場合は、デフォルト値になること(valueにNULLを含むハッシュとNULL)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:null_hash] = nil
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null_hash] == @default_filters[:null_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueにNULLを含むハッシュとtrue)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:null_hash] = true
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null_hash] == @default_filters[:null_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueにNULLを含むハッシュとfalse)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:null_hash] = false
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null_hash] == @default_filters[:null_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueにNULLを含むハッシュと数値)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:null_hash] = 1
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null_hash] == @default_filters[:null_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueにNULLを含むハッシュと小数)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:null_hash] = 1.2
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null_hash] == @default_filters[:null_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueにNULLを含むハッシュと配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:null_hash] = []
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null_hash] == @default_filters[:null_hash]
    filters[:null_hash] = [{}]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null_hash] == @default_filters[:null_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueにNULLを含むハッシュと文字列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:null_hash] = 'test'
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null_hash] == @default_filters[:null_hash]
  end

  test "キーの数が異なる場合は、デフォルト値になること(valueにNULLを含むハッシュと文字列)2.7.0" do
    #キーの数を見ているかどうかのテストなので、１回のみテスト
    filters = @default_filters.deep_dup
    filters[:null_hash] = {:a => nil}
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null_hash] == @default_filters[:null_hash]
    filters[:null_hash] = {:a => nil, :b => nil, :c => nil}
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null_hash] == @default_filters[:null_hash]
    filters[:null_hash] = {}
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null_hash] == @default_filters[:null_hash]
  end

  test "キーにデフォルト値のキーと異なるキーがあれば、デフォルト値になること(valueにNULLを含むハッシュと文字列)2.7.0" do
    #キーを見ているかどうかのテストなので、１回のみテスト
    filters = @default_filters.deep_dup
    filters[:null_hash] = {:c => nil}
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null_hash] == @default_filters[:null_hash]
    filters[:null_hash] = {:c => nil, :a => nil}
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null_hash] == @default_filters[:null_hash]
  end

  test "型が同じ場合は、指定した値が設定されること(valueにNULLを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:null_hash] = { :b => nil, :a => nil }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null_hash] == filters[:null_hash]
  end

  test "valueがnilの場合は、valueの型が違っても指定した値が設定されること(valueにNULLを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:null_hash] = { :b => nil, :a => 1 }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null_hash] == filters[:null_hash]
  end

  #valuesがあるデータのテスト
  test "valuesに含まれない値が指定されている場合は、デフォルト値になること(valueにNULLを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:null_hash_with_values] = {:b => nil, :c => nil}
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:null_hash_with_values] == filters[:null_hash_with_values]
    assert filterd_filters[:null_hash_with_values] == @default_filters[:null_hash_with_values]
  end

  test "valuesに含まれる値が指定されている場合は、指定した値が設定されること(valueにNULLを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:null_hash_with_values] = {:b => nil, :a => nil}
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null_hash_with_values] == filters[:null_hash_with_values]
    assert_not filterd_filters[:null_hash_with_values] == @default_filters[:null_hash_with_values]
  end

  #valueが文字列のハッシュのデータのテスト
  test "型が異なる場合は、デフォルト値になること(valueが文字列のハッシュとtrueを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:string_hash] = { :a => true }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:string_hash] == @default_filters[:string_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueが文字列のハッシュとfalseを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:string_hash] = { :a => false }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:string_hash] == @default_filters[:string_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueが文字列のハッシュと数値を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:string_hash] = { :a => 1 }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:string_hash] == @default_filters[:string_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueが文字列のハッシュと小数を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:string_hash] = { :a => 1.2 }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:string_hash] == @default_filters[:string_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueが文字列のハッシュと配列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:string_hash] = { :a => [] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:string_hash] == @default_filters[:string_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueが文字列のハッシュとハッシュを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:string_hash] = { :a => {} }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:string_hash] == @default_filters[:string_hash]
  end

  test "型が同じ場合は、指定した値が設定されること(valueが文字列のハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:string_hash] = { :a => 'testtest' }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:string_hash] == filters[:string_hash]
  end

  test "valueがnilの場合は、valueの型が違っても指定した値が設定されること(valueが文字列のハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:string_hash] = { :a => nil }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:string_hash] == filters[:string_hash]
  end

  #valuesがあるデータのテスト
  test "valuesに含まれない値が指定されている場合は、デフォルト値になること(valueが文字列のハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:string_hash_with_values] = {:a => 'test3'}
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:string_hash_with_values] == filters[:string_hash_with_values]
    assert filterd_filters[:string_hash_with_values] == @default_filters[:string_hash_with_values]
  end

  test "valuesに含まれる値が指定されている場合は、指定した値が設定されること(valueが文字列のハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:string_hash_with_values] = {:a => 'test2'}
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:string_hash_with_values] == filters[:string_hash_with_values]
    assert_not filterd_filters[:string_hash_with_values] == @default_filters[:string_hash_with_values]
  end

  #valueが数値のハッシュのデータのテスト
  test "型が異なる場合は、デフォルト値になること(valueが数値のハッシュとtrueを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:int_hash] = { :a => true }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:int_hash] == @default_filters[:int_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueが数値のハッシュとfalseを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:int_hash] = { :a => false }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:int_hash] == @default_filters[:int_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueが数値のハッシュと文字列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:int_hash] = { :a => '1' }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:int_hash] == @default_filters[:int_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueが数値のハッシュと小数を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:int_hash] = { :a => 1.2 }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:int_hash] == @default_filters[:int_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueが数値のハッシュと配列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:int_hash] = { :a => [] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:int_hash] == @default_filters[:int_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueが数値のハッシュとハッシュを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:int_hash] = { :a => {} }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:int_hash] == @default_filters[:int_hash]
  end

  test "型が同じ場合は、指定した値が設定されること(valueが数値のハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:int_hash] = { :a => 100 }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:int_hash] == filters[:int_hash]
  end

  test "valueがnilの場合は、valueの型が違っても指定した値が設定されること(valueが数値のハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:int_hash] = { :a => nil }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:int_hash] == filters[:int_hash]
  end

  #valuesがあるデータのテスト
  test "valuesに含まれない値が指定されている場合は、デフォルト値になること(valueが数値のハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:int_hash_with_values] = { :a => 1, :b => 6 }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:int_hash_with_values] == filters[:int_hash_with_values]
    assert filterd_filters[:int_hash_with_values] == @default_filters[:int_hash_with_values]
  end

  test "valuesに含まれる値が指定されている場合は、指定した値が設定されること(valueが数値のハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:int_hash_with_values] = { :a => 5, :b => 2 }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:int_hash_with_values] == filters[:int_hash_with_values]
    assert_not filterd_filters[:int_hash_with_values] == @default_filters[:int_hash_with_values]
  end

  #valueが小数のハッシュのデータのテスト
  test "型が異なる場合は、デフォルト値になること(valueが小数のハッシュとtrueを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:float_hash] = { :a => true }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:float_hash] == @default_filters[:float_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueが小数のハッシュとfalseを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:float_hash] = { :a => false }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:float_hash] == @default_filters[:float_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueが小数のハッシュと文字列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:float_hash] = { :a => '1.1' }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:float_hash] == @default_filters[:float_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueが小数のハッシュと数値を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:float_hash] = { :a => 1 }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:float_hash] == @default_filters[:float_hash]
  end     
         
  test "型が異なる場合は、デフォルト値になること(valueが小数のハッシュと配列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:float_hash] = { :a => [1.1] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:float_hash] == @default_filters[:float_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueが小数のハッシュとハッシュを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:float_hash] = { :a => { :a => 1.1 } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:float_hash] == @default_filters[:float_hash]
  end
    
  test "型が同じ場合は、指定した値が設定されること(valueが小数のハッシュ)2.7.0" do
    filters = @default_filters.deep_dup 
    filters[:float_hash] = { :a => 10.1 } 
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:float_hash] == filters[:float_hash]
  end

  test "valueがnilの場合は、valueの型が違っても指定した値が設定されること(valueが小数のハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:float_hash] = { :a => nil }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:float_hash] == filters[:float_hash]
  end

  #valuesがあるデータのテスト
  test "valuesに含まれない値が指定されている場合は、デフォルト値になること(valueが小数のハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:float_hash_with_values] = { :a => 1.0 }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:float_hash_with_values] == filters[:float_hash_with_values]
    assert filterd_filters[:float_hash_with_values] == @default_filters[:float_hash_with_values]
  end

  test "valuesに含まれる値が指定されている場合は、指定した値が設定されること(valueが小数のハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:float_hash_with_values] = { :a => 1.3 }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:float_hash_with_values] == filters[:float_hash_with_values]
    assert_not filterd_filters[:float_hash_with_values] == @default_filters[:float_hash_with_values]
  end

  #valueが真偽のハッシュのデータのテスト
  test "型が異なる場合は、デフォルト値になること(valueが真偽のハッシュと数値を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:bool_hash] = { :b => 1 }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:bool_hash] == @default_filters[:bool_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueが真偽のハッシュと文字列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:bool_hash] = { :b => '2' }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:bool_hash] == @default_filters[:bool_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueが真偽のハッシュと小数を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:bool_hash] = { :b => 1.2 }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:bool_hash] == @default_filters[:bool_hash]
  end     
         
  test "型が異なる場合は、デフォルト値になること(valueが真偽のハッシュと配列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:bool_hash] = { :b => [] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:bool_hash] == @default_filters[:bool_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueが真偽のハッシュとハッシュを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:bool_hash] = { :b => {} }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:bool_hash] == @default_filters[:bool_hash]
  end
    
  test "型が同じ場合は、指定した値が設定されること(valueが真偽のハッシュ)2.7.0" do
    filters = @default_filters.deep_dup 
    filters[:bool_hash] = { :b => true } 
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:bool_hash] == filters[:bool_hash]
  end

  test "valueがnilの場合は、valueの型が違っても指定した値が設定されること(valueが真偽のハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:bool_hash] = { :b => nil }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:bool_hash] == filters[:bool_hash]
  end

  #valuesがあるデータのテスト
  test "valuesに含まれない値が指定されている場合は、デフォルト値になること(valueが真偽のハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:bool_hash_with_values] = { :a => false, :b => true }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:bool_hash_with_values] == filters[:bool_hash_with_values]
    assert filterd_filters[:bool_hash_with_values] == @default_filters[:bool_hash_with_values]
  end

  test "valuesに含まれる値が指定されている場合は、指定した値が設定されること(valueが真偽のハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:bool_hash_with_values] = { :a => false, :b => false }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:bool_hash_with_values] == filters[:bool_hash_with_values]
    assert_not filterd_filters[:bool_hash_with_values] == @default_filters[:bool_hash_with_values]
  end

  #valueが配列のハッシュのデータのテスト
  test "型が異なる場合は、デフォルト値になること(valueが配列のハッシュとtrueを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_hash] = { :a => true }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_hash] == @default_filters[:array_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueが配列のハッシュとfalseを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_hash] = { :a => false }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_hash] == @default_filters[:array_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueが配列のハッシュと数値を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_hash] = { :a => 1 }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_hash] == @default_filters[:array_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueが配列のハッシュと文字列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_hash] = { :a => '2' }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_hash] == @default_filters[:array_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueが配列のハッシュと小数を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_hash] = { :a => 1.2 }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_hash] == @default_filters[:array_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueが配列のハッシュとハッシュを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_hash] = { :a => {} }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_hash] == @default_filters[:array_hash]
  end

  test "型が同じ場合は、指定した値が設定されること(valueが配列のハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_hash] = { :a => [] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_hash] == filters[:array_hash]
    filters[:array_hash] = { :a => [1] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_hash] == filters[:array_hash]
  end

  test "valueがnilの場合は、valueの型が違っても指定した値が設定されること(valueが配列のハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_hash] = { :a => nil }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_hash] == filters[:array_hash]
  end
 
  #valuesがあるデータのテスト
  test "valuesに含まれない値が指定されている場合は、デフォルト値になること(valueが配列のハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_hash_with_values] = { :a => [ 2 ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:array_hash_with_values] == filters[:array_hash_with_values]
    assert filterd_filters[:array_hash_with_values] == @default_filters[:array_hash_with_values]
  end

  test "valuesに含まれる値が指定されている場合は、指定した値が設定されること(valueが配列のハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_hash_with_values] = { :a => [1] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_hash_with_values] == filters[:array_hash_with_values]
    assert_not filterd_filters[:array_hash_with_values] == @default_filters[:array_hash_with_values]
  end
  
  #valueの配列にNULLを含むハッシュのデータのテスト
  test "型が異なる場合は、デフォルト値になること(valueの配列にNULLを含むハッシュとvalueの配列にtrueを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_null_hash] = { :a => [ true ], :b => [ true ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_null_hash] == @default_filters[:array_null_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列にNULLを含むハッシュとvalueの配列にfalseを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_null_hash] = { :a => [ false ], :b => [ false ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_null_hash] == @default_filters[:array_null_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列にNULLを含むハッシュとvalueの配列に文字列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_null_hash] = { :a => [ '1.1' ], :b => [ 'test' ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_null_hash] == @default_filters[:array_null_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列にNULLを含むハッシュとvalueの配列に数値を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_null_hash] = { :a => [ 1 ], :b => [ 2 ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_null_hash] == @default_filters[:array_null_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列にNULLを含むハッシュとvalueの配列に配列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_null_hash] = { :a => [ [] ], :b => [ [] ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_null_hash] == @default_filters[:array_null_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列にNULLを含むハッシュとvalueの配列にハッシュを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_null_hash] = { :a => [ {} ], :b => [ {} ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_null_hash] == @default_filters[:array_null_hash]
  end

  test "型が同じ場合は、指定した値が設定されること(valueの配列にNULLを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_null_hash] = { :a => [nil], :b => [nil] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_null_hash] == filters[:array_null_hash]
  end

  test "valueがnilの場合は、valueの型が違っても指定した値が設定されること(valueの配列にNULLを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_null_hash] = { :a => nil, :b => nil }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_null_hash] == filters[:array_null_hash]
  end

  #valuesがあるデータのテスト
  test "valuesに含まれない値が指定されている場合は、デフォルト値になること(valueの配列にNULLを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_null_hash_with_values] = { :a => [nil,nil], :b => [nil] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:array_null_hash_with_values] == filters[:array_null_hash_with_values]
    assert filterd_filters[:array_null_hash_with_values] == @default_filters[:array_null_hash_with_values]
  end

  test "valuesに含まれる値が指定されている場合は、指定した値が設定されること(valueの配列にNULLを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_null_hash_with_values] = { :a => [nil], :b => [nil] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_null_hash_with_values] == filters[:array_null_hash_with_values]
    assert_not filterd_filters[:array_null_hash_with_values] == @default_filters[:array_null_hash_with_values]
  end

  #valueの配列に数値を含むハッシュのデータのテスト
  test "型が異なる場合は、デフォルト値になること(valueの配列に数値を含むハッシュとvalueの配列にtrueを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_int_hash] = { :a => [ true ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_int_hash] == @default_filters[:array_int_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列に数値を含むハッシュとvalueの配列にfalseを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_int_hash] = { :a => [ false ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_int_hash] == @default_filters[:array_int_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列に数値を含むハッシュとvalueの配列にNULLを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_int_hash] = { :a => [ nil ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_int_hash] == @default_filters[:array_int_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列に数値を含むハッシュとvalueの配列に文字列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_int_hash] = { :a => [ '1' ]  }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_int_hash] == @default_filters[:array_int_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列に数値を含むハッシュとvalueの配列に小数を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_int_hash] = { :a => [ 1.1 ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_int_hash] == @default_filters[:array_int_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列に数値を含むハッシュとvalueの配列に配列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_int_hash] = { :a => [ [] ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_int_hash] == @default_filters[:array_int_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列に数値を含むハッシュとvalueの配列にハッシュを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_int_hash] = { :a => [ {} ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_int_hash] == @default_filters[:array_int_hash]
  end

  test "型が同じ場合は、指定した値が設定されること(valueの配列に数値を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_int_hash] = { :a => [3]  }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_int_hash] == filters[:array_int_hash]
  end

  test "valueがnilの場合は、valueの型が違っても指定した値が設定されること(valueの配列に数値を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_int_hash] = { :a => nil }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_int_hash] == filters[:array_int_hash]
  end

  #valuesがあるデータのテスト
  test "valuesに含まれない値が指定されている場合は、デフォルト値になること(valueの配列に数値を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_int_hash_with_values] = { :a => [3]  }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:array_int_hash_with_values] == filters[:array_int_hash_with_values]
    assert filterd_filters[:array_int_hash_with_values] == @default_filters[:array_int_hash_with_values]
  end

  test "valuesに含まれる値が指定されている場合は、指定した値が設定されること(valueの配列に数値を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_int_hash_with_values] = { :a => [1,2] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_int_hash_with_values] == filters[:array_int_hash_with_values]
    assert_not filterd_filters[:array_int_hash_with_values] == @default_filters[:array_int_hash_with_values]
  end

  #valueの配列に小数を含むハッシュのデータのテスト
  test "型が異なる場合は、デフォルト値になること(valueの配列に小数を含むハッシュとvalueの配列にtrueを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_float_hash] = { :a => [ true ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_float_hash] == @default_filters[:array_float_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列に小数を含むハッシュとvalueの配列にfalseを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_float_hash] = { :a => [ false ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_float_hash] == @default_filters[:array_float_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列に小数を含むハッシュとvalueの配列にNULLを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_float_hash] = { :a => [ nil ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_float_hash] == @default_filters[:array_float_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列に小数を含むハッシュとvalueの配列に文字列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_float_hash] = { :a => [ '1' ]  }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_float_hash] == @default_filters[:array_float_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列に小数を含むハッシュとvalueの配列に数値を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_float_hash] = { :a => [ 1 ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_float_hash] == @default_filters[:array_float_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列に小数を含むハッシュとvalueの配列に配列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_float_hash] = { :a => [ [] ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_float_hash] == @default_filters[:array_float_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列に小数を含むハッシュとvalueの配列にハッシュを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_float_hash] = { :a => [ {} ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_float_hash] == @default_filters[:array_float_hash]
  end

  test "型が同じ場合は、指定した値が設定されること(valueの配列に小数を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_float_hash] = { :a => [3.3]  }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_float_hash] == filters[:array_float_hash]
  end

  test "valueがnilの場合は、valueの型が違っても指定した値が設定されること(valueの配列に小数を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_float_hash] = { :a => nil }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_float_hash] == filters[:array_float_hash]
  end

  #valuesがあるデータのテスト
  test "valuesに含まれない値が指定されている場合は、デフォルト値になること(valueの配列に小数を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_float_hash_with_values] = { :a => [1.2]  }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:array_float_hash_with_values] == filters[:array_float_hash_with_values]
    assert filterd_filters[:array_float_hash_with_values] == @default_filters[:array_float_hash_with_values]
  end

  test "valuesに含まれる値が指定されている場合は、指定した値が設定されること(valueの配列に小数を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_float_hash_with_values] = { :a => [1.1, 2.2] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_float_hash_with_values] == filters[:array_float_hash_with_values]
    assert_not filterd_filters[:array_float_hash_with_values] == @default_filters[:array_float_hash_with_values]
  end

  #valueの配列に文字列を含むハッシュのデータのテスト
  test "型が異なる場合は、デフォルト値になること(valueの配列に文字列を含むハッシュとvalueの配列にtrueを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_string_hash] = { :a => [ true ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_string_hash] == @default_filters[:array_string_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列に文字列を含むハッシュとvalueの配列にfalseを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_string_hash] = { :a => [ false ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_string_hash] == @default_filters[:array_string_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列に文字列を含むハッシュとvalueの配列にNULLを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_string_hash] = { :a => [ nil ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_string_hash] == @default_filters[:array_string_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列に文字列を含むハッシュとvalueの配列に数値を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_string_hash] = { :a => [ 1 ]  }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_string_hash] == @default_filters[:array_string_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列に文字列を含むハッシュとvalueの配列に小数を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_string_hash] = { :a => [ 1.1 ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_string_hash] == @default_filters[:array_string_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列に文字列を含むハッシュとvalueの配列に配列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_string_hash] = { :a => [ ['test'] ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_string_hash] == @default_filters[:array_string_hash]
    filters[:array_string_hash] = { :a => [ [] ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_string_hash] == @default_filters[:array_string_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列に文字列を含むハッシュとvalueの配列にハッシュを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_string_hash] = { :a => [ {:a => 'test'} ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_string_hash] == @default_filters[:array_string_hash]
    filters[:array_string_hash] = { :a => [ {} ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_string_hash] == @default_filters[:array_string_hash]
  end

  test "型が同じ場合は、指定した値が設定されること(valueの配列に文字列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_string_hash] = { :a => ['3']  }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_string_hash] == filters[:array_string_hash]
  end

  test "valueがnilの場合は、valueの型が違っても指定した値が設定されること(valueの配列に文字列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_string_hash] = { :a => nil }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_string_hash] == filters[:array_string_hash]
  end

  #valuesがあるデータのテスト
  test "valuesに含まれない値が指定されている場合は、デフォルト値になること(valueの配列に文字列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_string_hash_with_values] = { :a => ['test2']  }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:array_string_hash_with_values] == filters[:array_string_hash_with_values]
    assert filterd_filters[:array_string_hash_with_values] == @default_filters[:array_string_hash_with_values]
  end

  test "valuesに含まれる値が指定されている場合は、指定した値が設定されること(valueの配列に文字列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_string_hash_with_values] = { :a => ['test1'] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_string_hash_with_values] == filters[:array_string_hash_with_values]
    assert_not filterd_filters[:array_string_hash_with_values] == @default_filters[:array_string_hash_with_values]
  end

  #valueの配列に真偽を含むハッシュのデータのテスト
  test "型が異なる場合は、デフォルト値になること(valueの配列に真偽を含むハッシュとvalueの配列にNULLを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_bool_hash] = { :a => [ nil ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_bool_hash] == @default_filters[:array_bool_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列に真偽を含むハッシュとvalueの配列に文字列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_bool_hash] = { :a => [ '1' ]  }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_bool_hash] == @default_filters[:array_bool_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列に真偽を含むハッシュとvalueの配列に小数を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_bool_hash] = { :a => [ 1.1 ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_bool_hash] == @default_filters[:array_bool_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列に真偽を含むハッシュとvalueの配列に数値を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_bool_hash] = { :a => [ 1 ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_bool_hash] == @default_filters[:array_bool_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列に真偽を含むハッシュとvalueの配列に配列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_bool_hash] = { :a => [ [] ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_bool_hash] == @default_filters[:array_bool_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列に真偽を含むハッシュとvalueの配列にハッシュを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_bool_hash] = { :a => [ {} ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_bool_hash] == @default_filters[:array_bool_hash]
  end

  test "型が同じ場合は、指定した値が設定されること(valueの配列に真偽を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_bool_hash] = { :a => [false]  }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_bool_hash] == filters[:array_bool_hash]
    filters[:array_bool_hash] = { :a => [true, false]  }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_bool_hash] == filters[:array_bool_hash]
  end

  test "valueがnilの場合は、valueの型が違っても指定した値が設定されること(valueの配列に真偽を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_bool_hash] = { :a => nil }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_bool_hash] == filters[:array_bool_hash]
  end
  #valuesがあるデータのテスト
  test "valuesに含まれない値が指定されている場合は、デフォルト値になること(valueの配列に真偽を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_bool_hash_with_values] = { :a => [true]  }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:array_bool_hash_with_values] == filters[:array_bool_hash_with_values]
    assert filterd_filters[:array_bool_hash_with_values] == @default_filters[:array_bool_hash_with_values]
  end

  test "valuesに含まれる値が指定されている場合は、指定した値が設定されること(valueの配列に真偽を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_bool_hash_with_values] = { :a => [false, true] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_bool_hash_with_values] == filters[:array_bool_hash_with_values]
    assert_not filterd_filters[:array_bool_hash_with_values] == @default_filters[:array_bool_hash_with_values]
  end

  #valueの配列に配列を含むハッシュのデータのテスト
  test "型が異なる場合は、デフォルト値になること(valueの配列に配列を含むハッシュとvalueの配列にtrueを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_array_hash] = { :a => [ true ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array_hash] == @default_filters[:array_array_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列に配列を含むハッシュとvalueの配列にfalseを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_array_hash] = { :a => [ false ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array_hash] == @default_filters[:array_array_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列に配列を含むハッシュとvalueの配列にNULLを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_array_hash] = { :a => [ nil ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array_hash] == @default_filters[:array_array_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列に配列を含むハッシュとvalueの配列に文字列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_array_hash] = { :a => [ '1' ]  }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array_hash] == @default_filters[:array_array_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列に配列を含むハッシュとvalueの配列に数値を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_array_hash] = { :a => [ 1 ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array_hash] == @default_filters[:array_array_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列に配列を含むハッシュとvalueの配列に小数を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_array_hash] = { :a => [ 1.1 ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array_hash] == @default_filters[:array_array_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列に配列を含むハッシュとvalueの配列にハッシュを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_array_hash] = { :a => [ {} ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array_hash] == @default_filters[:array_array_hash]
  end

  test "配列の中身の型が異なる場合は、デフォルト値になること(valueの配列に配列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_array_hash] = { :a => [ nil ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array_hash] == @default_filters[:array_array_hash]
    filters = @default_filters.deep_dup
    filters[:array_array_hash] = { :a => [ 1 ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array_hash] == @default_filters[:array_array_hash]
    filters = @default_filters.deep_dup
    filters[:array_array_hash] = { :a => [ 1.1 ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array_hash] == @default_filters[:array_array_hash]
    filters = @default_filters.deep_dup
    filters[:array_array_hash] = { :a => [ true ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array_hash] == @default_filters[:array_array_hash]
    filters = @default_filters.deep_dup
    filters[:array_array_hash] = { :a => [ false ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array_hash] == @default_filters[:array_array_hash]
    filters = @default_filters.deep_dup
    filters[:array_array_hash] = { :a => [ {} ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array_hash] == @default_filters[:array_array_hash]
    filters = @default_filters.deep_dup
  end

  test "配列の中身が型の場合は、指定した値が設定されること(valueの配列に配列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_array_hash] = { :a => [ [] ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array_hash] == filters[:array_array_hash]
  end

  test "型が同じ場合は、指定した値が設定されること(valueの配列に配列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_array_hash] = { :a => [[]] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array_hash] == filters[:array_array_hash]
    filters[:array_array_hash] = { :a => [['testtest']] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array_hash] == filters[:array_array_hash]
  end

  test "valueがnilの場合は、valueの型が違っても指定した値が設定されること(valueの配列に配列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_array_hash] = { :a => nil }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array_hash] == filters[:array_array_hash]
  end
  #valuesがあるデータのテスト
  test "valuesに含まれない値が指定されている場合は、デフォルト値になること(valueの配列に配列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_array_hash_with_values] = { :a => [['test', 'test3']]  }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:array_array_hash_with_values] == filters[:array_array_hash_with_values]
    assert filterd_filters[:array_array_hash_with_values] == @default_filters[:array_array_hash_with_values]
  end

  test "valuesに含まれる値が指定されている場合は、指定した値が設定されること(valueの配列に配列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_array_hash_with_values] = { :a => [['test', 'test2']] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array_hash_with_values] == filters[:array_array_hash_with_values]
    assert_not filterd_filters[:array_array_hash_with_values] == @default_filters[:array_array_hash_with_values]
  end

  #valueの配列にハッシュを含むハッシュのデータのテスト
  test "型が異なる場合は、デフォルト値になること(valueの配列にハッシュを含むハッシュとvalueの配列にtrueを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_hash_hash] = { :a => [ true ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_hash_hash] == @default_filters[:array_hash_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列にハッシュを含むハッシュとvalueの配列にfalseを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_hash_hash] = { :a => [ false ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_hash_hash] == @default_filters[:array_hash_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列にハッシュを含むハッシュとvalueの配列にNULLを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_hash_hash] = { :a => [ nil ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_hash_hash] == @default_filters[:array_hash_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列にハッシュを含むハッシュとvalueの配列に文字列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_hash_hash] = { :a => [ '1' ]  }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_hash_hash] == @default_filters[:array_hash_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列にハッシュを含むハッシュとvalueの配列に数値を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_hash_hash] = { :a => [ 1 ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_hash_hash] == @default_filters[:array_hash_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列にハッシュを含むハッシュとvalueの配列に配列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_hash_hash] = { :a => [ [] ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_hash_hash] == @default_filters[:array_hash_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueの配列にハッシュを含むハッシュとvalueの配列に小数を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_hash_hash] = { :a => [ 1.1 ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_hash_hash] == @default_filters[:array_hash_hash]
  end

  test "型が同じ場合は、指定した値が設定されること(valueの配列にハッシュを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_hash_hash] = { :a =>  [ { :aa => 'testtest' } ]  }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_hash_hash] == filters[:array_hash_hash]
  end

  test "valueがnilの場合は、valueの型が違っても指定した値が設定されること(valueの配列にハッシュを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_hash_hash] = { :a => nil }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_hash_hash] == filters[:array_hash_hash]
  end

  #valuesがあるデータのテスト
  test "valuesに含まれない値が指定されている場合は、デフォルト値になること(valueの配列にハッシュを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_hash_hash_with_values] = { :a =>  [ { :aa => 'testtest' } ]  }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:array_hash_hash_with_values] == filters[:array_hash_hash_with_values]
    assert filterd_filters[:array_hash_hash_with_values] == @default_filters[:array_hash_hash_with_values]
  end

  test "valuesに含まれる値が指定されている場合は、指定した値が設定されること(valueの配列にハッシュを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_hash_hash_with_values] = { :a =>  [ { :aa => 'test2' } ] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_hash_hash_with_values] == filters[:array_hash_hash_with_values]
    assert_not filterd_filters[:array_hash_hash_with_values] == @default_filters[:array_hash_hash_with_values]
  end

  #以降はネストしたハッシュで、valuesのチェックとネストしている末尾のデータの型チェックテスト
  
  #valueのハッシュのvalueにNULLを含むハッシュのデータのテスト
  test "デフォルトがnilの場合は指定した値を設定できること(valueのハッシュのvalueにNULLを含むハッシュとvalueのハッシュのvalueにtrueを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_null_hash] = { :a => { :aa => true } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_null_hash] == filters[:nested_null_hash]
    filters[:nested_null_hash] = { :a => { :aa => false } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_null_hash] == filters[:nested_null_hash]
    filters[:nested_null_hash] = { :a => { :aa => 1.1 }  }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_null_hash] == filters[:nested_null_hash]
    filters[:nested_null_hash] = { :a => { :aa => '1' }  }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_null_hash] == filters[:nested_null_hash]
    filters[:nested_null_hash] = { :a => { :aa => 1 } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_null_hash] == filters[:nested_null_hash]
    filters[:nested_null_hash] = { :a => { :aa => [] } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_null_hash] == filters[:nested_null_hash]
    filters[:nested_null_hash] = { :a => { :aa => {} } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_null_hash] == filters[:nested_null_hash]
  end

  test "キーが異なる場合はデフォルト値になること(valueのハッシュのvalueにNULLを含むハッシュとvalueのハッシュのvalueにfalseを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_null_hash] = { :a => { :aaa => true } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_null_hash] == @default_filters[:nested_null_hash]
    filters[:nested_null_hash] = { :a => { :aa => true, :a => true } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_null_hash] == @default_filters[:nested_null_hash]
  end

  #valuesがあるデータのテスト
    test "valuesに含まれない値が指定されている場合は、デフォルト値になること(valueのハッシュのvalueにNULLを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_null_hash_with_values] = { :a => { :aa => 2 } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:nested_null_hash_with_values] == filters[:nested_null_hash_with_values]
    assert filterd_filters[:nested_null_hash_with_values] == @default_filters[:nested_null_hash_with_values]
  end

  test "valuesに含まれる値が指定されている場合は、指定した値が設定されること(valueのハッシュのvalueにNULLを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_null_hash_with_values] = { :a => { :aa => 1 } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_null_hash_with_values] == filters[:nested_null_hash_with_values]
    assert_not filterd_filters[:nested_null_hash_with_values] == @default_filters[:nested_null_hash_with_values]
  end

  #valueのハッシュのvalueに文字列を含むハッシュのデータのテスト
  test "型が異なる場合は、デフォルト値になること(valueのハッシュのvalueに文字列を含むハッシュとvalueのハッシュのvalueにtrueを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_string_hash] = { :a => { :aa => true } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_string_hash] == @default_filters[:nested_string_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueのハッシュのvalueに文字列を含むハッシュとvalueのハッシュのvalueにfalseを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_string_hash] = { :a => { :aa => false } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_string_hash] == @default_filters[:nested_string_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueのハッシュのvalueに文字列を含むハッシュとvalueのハッシュのvalueに小数を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_string_hash] = { :a => { :aa => 1.1 } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_string_hash] == @default_filters[:nested_string_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueのハッシュのvalueに文字列を含むハッシュとvalueのハッシュのvalueに数値を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_string_hash] = { :a => { :aa => 1 } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_string_hash] == @default_filters[:nested_string_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueのハッシュのvalueに文字列を含むハッシュとvalueのハッシュのvalueに配列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_string_hash] = { :a => { :aa => [] } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_string_hash] == @default_filters[:nested_string_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueのハッシュのvalueに文字列を含むハッシュとvalueのハッシュのvalueにハッシュを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_string_hash] = { :a => { :aa => {} } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_string_hash] == @default_filters[:nested_string_hash]
  end

  test "型が同じ場合は、指定した値が設定されること(valueのハッシュのvalueに文字列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_string_hash] = { :a =>  { :aa => '3.3' } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_string_hash] == filters[:nested_string_hash]
  end

  test "valueがnilの場合は、valueの型が違っても指定した値が設定されること(valueのハッシュのvalueに文字列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_string_hash] = { :a => { :aa => nil } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_string_hash] == filters[:nested_string_hash]
  end

  #valuesがあるデータのテスト
  test "valuesに含まれない値が指定されている場合は、デフォルト値になること(valueのハッシュのvalueに文字列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_string_hash_with_values] = {:a => { :aa => 'test3'}}
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:nested_string_hash_with_values] == filters[:nested_string_hash_with_values]
    assert filterd_filters[:nested_string_hash_with_values] == @default_filters[:nested_string_hash_with_values]
  end

  test "valuesに含まれる値が指定されている場合は、指定した値が設定されること(valueのハッシュのvalueに文字列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_string_hash_with_values] = {:a => { :aa => 'test2'}}
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_string_hash_with_values] == filters[:nested_string_hash_with_values]
    assert_not filterd_filters[:nested_string_hash_with_values] == @default_filters[:nested_string_hash_with_values]
  end

  #valueのハッシュのvalueに数値を含むハッシュのデータのテスト
  test "型が異なる場合は、デフォルト値になること(valueのハッシュのvalueに数値を含むハッシュとvalueのハッシュのvalueにtrueを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_int_hash] = { :a => { :aa => true } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_int_hash] == @default_filters[:nested_int_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueのハッシュのvalueに数値を含むハッシュとvalueのハッシュのvalueにfalseを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_int_hash] = { :a => { :aa => false } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_int_hash] == @default_filters[:nested_int_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueのハッシュのvalueに数値を含むハッシュとvalueのハッシュのvalueに小数を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_int_hash] = { :a => { :aa => 1.1 } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_int_hash] == @default_filters[:nested_int_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueのハッシュのvalueに数値を含むハッシュとvalueのハッシュのvalueに文字列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_int_hash] =  { :a => { :aa => 3 }, :b => { :bb => '3' } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_int_hash] == @default_filters[:nested_int_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueのハッシュのvalueに数値を含むハッシュとvalueのハッシュのvalueに配列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_int_hash] =  { :a => { :aa => [] }, :b => { :bb => 3 } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_int_hash] == @default_filters[:nested_int_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueのハッシュのvalueに数値を含むハッシュとvalueのハッシュのvalueにハッシュを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_int_hash] =  { :a => { :aa => {} }, :b => { :bb => {} } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_int_hash] == @default_filters[:nested_int_hash]
  end

  test "型が同じ場合は、指定した値が設定されること(valueのハッシュのvalueに数値を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_int_hash] = { :a => { :aa => 3 }, :b => { :bb => 3 } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_int_hash] == filters[:nested_int_hash]
  end

  test "valueがnilの場合は、valueの型が違っても指定した値が設定されること(valueのハッシュのvalueに数値を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_int_hash] =  { :a => { :aa => nil }, :b => { :bb => 3 } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_int_hash] == filters[:nested_int_hash]
    filters[:nested_int_hash] =  { :a => { :aa => nil }, :b => { :bb => nil } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_int_hash] == filters[:nested_int_hash]
  end

  #valuesがあるデータのテスト
  test "valuesに含まれない値が指定されている場合は、デフォルト値になること(valueのハッシュのvalueに数値を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_int_hash_with_values] = {:a =>  { :aa => 2, :bb => 3 }}
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:nested_int_hash_with_values] == filters[:nested_int_hash_with_values]
    assert filterd_filters[:nested_int_hash_with_values] == @default_filters[:nested_int_hash_with_values]
  end

  test "valuesに含まれる値が指定されている場合は、指定した値が設定されること(valueのハッシュのvalueに数値を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_int_hash_with_values] = {:a => { :aa => 2, :bb => 5 }}
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_int_hash_with_values] == filters[:nested_int_hash_with_values]
    assert_not filterd_filters[:nested_int_hash_with_values] == @default_filters[:nested_int_hash_with_values]
  end

  #valueのハッシュのvalueに小数を含むハッシュのデータのテスト
  test "型が異なる場合は、デフォルト値になること(valueのハッシュのvalueに小数を含むハッシュとvalueのハッシュのvalueにtrueを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_float_hash] = { :a => { :aa => true } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_float_hash] == @default_filters[:nested_float_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueのハッシュのvalueに小数を含むハッシュとvalueのハッシュのvalueにfalseを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_float_hash] = { :a => { :aa => false } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_float_hash] == @default_filters[:nested_float_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueのハッシュのvalueに小数を含むハッシュとvalueのハッシュのvalueに文字列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_float_hash] = { :a => { :aa => '1.1' } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_float_hash] == @default_filters[:nested_float_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueのハッシュのvalueに小数を含むハッシュとvalueのハッシュのvalueに数値を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_float_hash] = { :a => { :aa => 1 } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_float_hash] == @default_filters[:nested_float_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueのハッシュのvalueに小数を含むハッシュとvalueのハッシュのvalueに配列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_float_hash] = { :a => { :aa => [] } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_float_hash] == @default_filters[:nested_float_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueのハッシュのvalueに小数を含むハッシュとvalueのハッシュのvalueにハッシュを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_float_hash] = { :a => { :aa => {} } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_float_hash] == @default_filters[:nested_float_hash]
  end

  test "型が同じ場合は、指定した値が設定されること(valueのハッシュのvalueに小数を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_float_hash] = { :a =>  { :aa => 3.3 } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_float_hash] == filters[:nested_float_hash]
  end

  test "valueがnilの場合は、valueの型が違っても指定した値が設定されること(valueのハッシュのvalueに小数を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_float_hash] = { :a => { :aa => nil } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_float_hash] == filters[:nested_float_hash]
  end

  #valuesがあるデータのテスト
  test "valuesに含まれない値が指定されている場合は、デフォルト値になること(valueのハッシュのvalueに小数を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_float_hash_with_values] = {:b => { :bb => 2.1}, :a => { :aa => 1.1 }}
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:nested_float_hash_with_values] == filters[:nested_float_hash_with_values]
    assert filterd_filters[:nested_float_hash_with_values] == @default_filters[:nested_float_hash_with_values]
  end

  test "valuesに含まれる値が指定されている場合は、指定した値が設定されること(valueのハッシュのvalueに小数を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_float_hash_with_values] = {:b => { :bb => 1.5}, :a => { :aa => 1.5 }}
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_float_hash_with_values] == filters[:nested_float_hash_with_values]
    assert_not filterd_filters[:nested_float_hash_with_values] == @default_filters[:nested_float_hash_with_values]
  end

  #valueのハッシュのvalueに真偽を含むハッシュのデータのテスト
  test "型が異なる場合は、デフォルト値になること(valueのハッシュのvalueに真偽を含むハッシュとvalueのハッシュのvalueに文字列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_bool_hash] = { :a => { :aa => 'false' } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_bool_hash] == @default_filters[:nested_bool_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueのハッシュのvalueに真偽を含むハッシュとvalueのハッシュのvalueに小数を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_bool_hash] = { :a => { :aa => 1.1 } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_bool_hash] == @default_filters[:nested_bool_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueのハッシュのvalueに真偽を含むハッシュとvalueのハッシュのvalueに数値を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_bool_hash] = { :a => { :aa => 1 } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_bool_hash] == @default_filters[:nested_bool_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueのハッシュのvalueに真偽を含むハッシュとvalueのハッシュのvalueに配列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_bool_hash] = { :a => { :aa => [] } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_bool_hash] == @default_filters[:nested_bool_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueのハッシュのvalueに真偽を含むハッシュとvalueのハッシュのvalueにハッシュを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_bool_hash] = { :a => { :aa => {} } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_bool_hash] == @default_filters[:nested_bool_hash]
  end

  test "型が同じ場合は、指定した値が設定されること(valueのハッシュのvalueに真偽を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_bool_hash] = { :a =>  { :aa => false } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_bool_hash] == filters[:nested_bool_hash]
    filters[:nested_bool_hash] = { :a =>  { :aa => true } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_bool_hash] == filters[:nested_bool_hash]
  end

  test "valueがnilの場合は、valueの型が違っても指定した値が設定されること(valueのハッシュのvalueに真偽を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_bool_hash] = { :a => { :aa => nil } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_bool_hash] == filters[:nested_bool_hash]
  end
  #valuesがあるデータのテスト
  test "valuesに含まれない値が指定されている場合は、デフォルト値になること(valueのハッシュのvalueに真偽を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_bool_hash_with_values] = {:a => { :aa => true }}
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:nested_bool_hash_with_values] == filters[:nested_bool_hash_with_values]
    assert filterd_filters[:nested_bool_hash_with_values] == @default_filters[:nested_bool_hash_with_values]
  end

  test "valuesに含まれる値が指定されている場合は、指定した値が設定されること(valueのハッシュのvalueに真偽を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_bool_hash_with_values] = {:a => { :aa => nil }}
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_bool_hash_with_values] == filters[:nested_bool_hash_with_values]
    assert_not filterd_filters[:nested_bool_hash_with_values] == @default_filters[:nested_bool_hash_with_values]
  end

  #valueのハッシュのvalueに配列を含むハッシュのデータのテスト
  test "型が異なる場合は、デフォルト値になること(valueのハッシュのvalueに配列を含むハッシュとvalueのハッシュのvalueにtrueを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_array_hash] = { :a => { :aa => true } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_array_hash] == @default_filters[:nested_array_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueのハッシュのvalueに配列を含むハッシュとvalueのハッシュのvalueにfalseを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_array_hash] = { :a => { :aa => false } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_array_hash] == @default_filters[:nested_array_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueのハッシュのvalueに配列を含むハッシュとvalueのハッシュのvalueに小数を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_array_hash] = { :a => { :aa => 1.1 } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_array_hash] == @default_filters[:nested_array_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueのハッシュのvalueに配列を含むハッシュとvalueのハッシュのvalueに数値を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_array_hash] = { :a => { :aa => 1 } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_array_hash] == @default_filters[:nested_array_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueのハッシュのvalueに配列を含むハッシュとvalueのハッシュのvalueに文字列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_array_hash] = { :a => { :aa => 'test' } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_array_hash] == @default_filters[:nested_array_hash]
  end

  test "型が異なる場合は、デフォルト値になること(valueのハッシュのvalueに配列を含むハッシュとvalueのハッシュのvalueにハッシュを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_array_hash] = { :a => { :aa => {} } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_array_hash] == @default_filters[:nested_array_hash]
  end

  test "配列の中身の型が異なる場合は、デフォルト値になること(valueのハッシュのvalueに配列を含むハッシュとvalueのハッシュのvalueにハッシュを含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_array_hash] = { :a => { :aa => ['50'] } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_array_hash] == @default_filters[:nested_array_hash]
  end

  test "型が同じ場合は、指定した値が設定されること(valueのハッシュのvalueに配列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_array_hash] = { :a =>  { :aa => [50] } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_array_hash] == filters[:nested_array_hash]
  end

  test "valueがnilの場合は、valueの型が違っても指定した値が設定されること(valueのハッシュのvalueに配列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_array_hash] = { :a => { :aa => nil } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_array_hash] == filters[:nested_array_hash]
  end

  #valuesがあるデータのテスト
  test "valuesに含まれない値が指定されている場合は、デフォルト値になること(valueのハッシュのvalueに配列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_array_hash_with_values] = { :a => { :aa => [2] }, :b => { :bb => [1, 2] } }

    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:nested_array_hash_with_values] == filters[:nested_array_hash_with_values]
    assert filterd_filters[:nested_array_hash_with_values] == @default_filters[:nested_array_hash_with_values]
  end

  test "valuesに含まれる値が指定されている場合は、指定した値が設定されること(valueのハッシュのvalueに配列を含むハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:nested_array_hash_with_values] = {:a => { :aa => [2] }, :b => { :bb => [1] }}
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:nested_array_hash_with_values] == filters[:nested_array_hash_with_values]
    assert_not filterd_filters[:nested_array_hash_with_values] == @default_filters[:nested_array_hash_with_values]
  end

  #以下、type_sourceのテスト
  test "type_sourceに値があり、その値の型と同じ型なら指定した値を設定できること(ハッシュと配列以外)2.7.0" do
    #ハッシュと配列以外はtype_sourceを指定するケース(意味)はなさそうだが、指定しても問題ないことを確認する
    filters = @default_filters.deep_dup
    filters[:null_with_type_source] = nil
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:null_with_type_source] == filters[:null_with_type_source]
    filters = @default_filters.deep_dup
    filters[:string_with_type_source] = '2'
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:string_with_type_source] == filters[:string_with_type_source]
    filters = @default_filters.deep_dup
    filters[:int_with_type_source] = 3
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:int_with_type_source] == filters[:int_with_type_source]
    filters = @default_filters.deep_dup
    filters[:float_with_type_source] = 5.5
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:float_with_type_source] == filters[:float_with_type_source]
    filters = @default_filters.deep_dup
    filters[:true_with_type_source] = false #falseも同じ型
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:true_with_type_source] == filters[:true_with_type_source]
    filters = @default_filters.deep_dup
    filters[:false_with_type_source] = true #trueも同じ型
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:false_with_type_source] == filters[:false_with_type_source]
    filters = @default_filters.deep_dup
  end

  test "type_sourceに値があり、その値の型と異なる型なら指定した値を設定できないこと(ハッシュと配列以外)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:null_with_type_source] = '1'
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:null_with_type_source] == filters[:null_with_type_source]
    filters = @default_filters.deep_dup
    filters[:string_with_type_source] = 2
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:string_with_type_source] == filters[:string_with_type_source]
    filters = @default_filters.deep_dup
    filters[:int_with_type_source] = 3.3
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:int_with_type_source] == filters[:int_with_type_source]
    filters = @default_filters.deep_dup
    filters[:float_with_type_source] = 5
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:float_with_type_source] == filters[:float_with_type_source]
    filters = @default_filters.deep_dup
  end

  test "type_sourceに値があり、その値の型と同じ型なら指定した値を設定できること(配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_with_type_source_string] = ['test']
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_with_type_source_string] == filters[:array_with_type_source_string]
    filters = @default_filters.deep_dup
    filters[:array_with_type_source_int] = [1]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_with_type_source_int] == filters[:array_with_type_source_int]
    filters = @default_filters.deep_dup
    filters[:array_with_type_source_float] = [3.3]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_with_type_source_float] == filters[:array_with_type_source_float]
    filters = @default_filters.deep_dup
    filters[:array_with_type_source_true] = [false]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_with_type_source_true] == filters[:array_with_type_source_true]
    filters = @default_filters.deep_dup
    filters[:array_with_type_source_false] = [false]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_with_type_source_false] == filters[:array_with_type_source_false]
    filters = @default_filters.deep_dup
    filters[:array_with_type_source_array] = [[]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_with_type_source_array] == filters[:array_with_type_source_array]
    filters[:array_with_type_source_array] = [[1]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_with_type_source_array] == filters[:array_with_type_source_array]
    filters = @default_filters.deep_dup
    filters[:array_with_type_source_hash] = [ {:a => 3}]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_with_type_source_hash] == filters[:array_with_type_source_hash]
    filters = @default_filters.deep_dup
    filters[:array_with_type_source_null] = [nil]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_with_type_source_null] == filters[:array_with_type_source_null]
  end

  test "type_sourceに値があり、その値の型と異なる型なら指定した値を設定できないこと(配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_with_type_source_string] = [true]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:array_with_type_source_string] == filters[:array_with_type_source_string]
    filters = @default_filters.deep_dup
    filters[:array_with_type_source_int] = [1.1]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:array_with_type_source_int] == filters[:array_with_type_source_int]
    filters = @default_filters.deep_dup
    filters[:array_with_type_source_float] = [3]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:array_with_type_source_float] == filters[:array_with_type_source_float]
    filters = @default_filters.deep_dup
    filters[:array_with_type_source_true] = [1]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:array_with_type_source_true] == filters[:array_with_type_source_true]
    filters = @default_filters.deep_dup
    filters[:array_with_type_source_false] = ['false']
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:array_with_type_source_false] == filters[:array_with_type_source_false]
    filters = @default_filters.deep_dup
    filters[:array_with_type_source_array] = [{}]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:array_with_type_source_array] == filters[:array_with_type_source_array]
    filters = @default_filters.deep_dup
    filters[:array_with_type_source_hash] = [[]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:array_with_type_source_hash] == filters[:array_with_type_source_hash]
    filters = @default_filters.deep_dup
    filters[:array_with_type_source_null] = ['nil']
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:array_with_type_source_null] == filters[:array_with_type_source_null]
  end

  test "type_sourceに値があり、その値の型と同じ型なら指定した値を設定できること(2次元以上の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_array_with_type_source_string] = [['test', 'test2']]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array_with_type_source_string] == filters[:array_array_with_type_source_string]
    filters = @default_filters.deep_dup
    filters[:array_array_with_type_source_int] = [[1]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array_with_type_source_int] == filters[:array_array_with_type_source_int]
    filters = @default_filters.deep_dup
    filters[:array_array_with_type_source_float] = [[3.3, 5.5]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array_with_type_source_float] == filters[:array_array_with_type_source_float]
    filters = @default_filters.deep_dup
    filters[:array_array_with_type_source_true] = [[false]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array_with_type_source_true] == filters[:array_array_with_type_source_true]
    filters = @default_filters.deep_dup
    filters[:array_array_with_type_source_false] = [[false,true]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array_with_type_source_false] == filters[:array_array_with_type_source_false]
    filters = @default_filters.deep_dup
    filters[:array_array_with_type_source_array] = [[[]]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array_with_type_source_array] == filters[:array_array_with_type_source_array]
    filters[:array_array_with_type_source_array] = [[[1,2]]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array_with_type_source_array] == filters[:array_array_with_type_source_array]
    filters = @default_filters.deep_dup
    filters[:array_array_with_type_source_hash] = [[{:a => 200}]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array_with_type_source_hash] == filters[:array_array_with_type_source_hash]
    filters = @default_filters.deep_dup
    filters[:array_array_with_type_source_null] = [[nil]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:array_array_with_type_source_null] == filters[:array_array_with_type_source_null]
  end

  test "type_sourceに値があり、その値の型と異なる型なら指定した値を設定できないこと(2次元以上の配列)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:array_array_with_type_source_string] = [[true]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:array_array_with_type_source_string] == filters[:array_array_with_type_source_string]
    filters = @default_filters.deep_dup
    filters[:array_array_with_type_source_int] = [[1.1]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:array_array_with_type_source_int] == filters[:array_array_with_type_source_int]
    filters = @default_filters.deep_dup
    filters[:array_array_with_type_source_float] = [[3, 5]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:array_array_with_type_source_float] == filters[:array_array_with_type_source_float]
    filters = @default_filters.deep_dup
    filters[:array_array_with_type_source_true] = [[1,2]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:array_array_with_type_source_true] == filters[:array_array_with_type_source_true]
    filters = @default_filters.deep_dup
    filters[:array_array_with_type_source_false] = [['false']]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:array_array_with_type_source_false] == filters[:array_array_with_type_source_false]
    filters = @default_filters.deep_dup
    filters[:array_array_with_type_source_array] = [['test']]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:array_array_with_type_source_array] == filters[:array_array_with_type_source_array]
    filters = @default_filters.deep_dup
    filters[:array_array_with_type_source_hash] = [[[]]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:array_array_with_type_source_hash] == filters[:array_array_with_type_source_hash]
    filters = @default_filters.deep_dup
    filters[:array_array_with_type_source_null] = [[{}]]
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:array_array_with_type_source_null] == filters[:array_array_with_type_source_null]
  end

  test "type_sourceに値があり、その値の型と同じ型なら指定した値を設定できること(ハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:hash_with_type_source_string] = { :a => 'test'}
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:hash_with_type_source_string] == filters[:hash_with_type_source_string], filterd_filters[:hash_with_type_source_string]
    filters = @default_filters.deep_dup
    filters[:hash_with_type_source_int] = { :a => 10 }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:hash_with_type_source_int] == filters[:hash_with_type_source_int]
    filters = @default_filters.deep_dup
    filters[:hash_with_type_source_float] = { :a => 10.1 } 
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:hash_with_type_source_float] == filters[:hash_with_type_source_float]
    filters = @default_filters.deep_dup
    filters[:hash_with_with_type_true] = { :a => false }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:hash_with_type_source_true] == filters[:hash_with_type_source_true]
    filters = @default_filters.deep_dup
    filters[:hash_with_type_source_false] = { :a => true }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:hash_with_type_source_false] == filters[:hash_with_type_source_false]
    filters = @default_filters.deep_dup
    filters[:hash_with_type_source_array] = { :a => [] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:hash_with_type_source_array] == filters[:hash_with_type_source_array]
    filters[:hash_with_type_source_array] = { :a => ['test'] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:hash_with_type_source_array] == filters[:hash_with_type_source_array]
    filters = @default_filters.deep_dup
    filters[:hash_with_type_source_hash] = { :a => {} }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:hash_with_type_source_hash] == filters[:hash_with_type_source_hash]
    filters = @default_filters.deep_dup
    filters[:hash_with_type_source_null] = { :a => nil }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:hash_with_type_source_null] == filters[:hash_with_type_source_null]
    filters[:hash_with_type_source_null] = { :a => 1 } #デフォルトnilには値を設定可能
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:hash_with_type_source_null] == filters[:hash_with_type_source_null]
    filters = @default_filters.deep_dup
    filters[:hash_with_type_source_array_hash] = { :a => [{}] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:hash_with_type_source_array_hash] == filters[:hash_with_type_source_array_hash]
    filters = @default_filters.deep_dup
    filters[:hash_with_type_source_array_hash_array] = {:a => [ {:bb => [] } ]}
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:hash_with_type_source_array_hash_array] == filters[:hash_with_type_source_array_hash_array]
    filters[:hash_with_type_source_array_hash_array] = {:a => [ {:bb => [1,2] } ]}
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:hash_with_type_source_array_hash_array] == filters[:hash_with_type_source_array_hash_array]
    filters[:hash_with_type_source_array_hash_array] = {:a => [ {:bb => [1] } ]}
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:hash_with_type_source_array_hash_array] == filters[:hash_with_type_source_array_hash_array]
    filters = @default_filters.deep_dup
    filters[:hash_with_type_source_hash_hash] = { :a => { :aa => {:a => 'test'} } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert filterd_filters[:hash_with_type_source_hash_hash] == filters[:hash_with_type_source_hash_hash]
  end

  test "type_sourceに値があり、その値の型と異なる型なら指定した値を設定できないこと(ハッシュ)2.7.0" do
    filters = @default_filters.deep_dup
    filters[:hash_with_type_source_string] = { :a => []}
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:hash_with_type_source_string] == filters[:hash_with_type_source_string], filterd_filters[:hash_with_type_source_string]
    filters = @default_filters.deep_dup
    filters[:hash_with_type_source_int] = { :a => 'test' }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:hash_with_type_source_int] == filters[:hash_with_type_source_int]
    filters = @default_filters.deep_dup
    filters[:hash_with_type_source_float] = { :a => 10 }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:hash_with_type_source_float] == filters[:hash_with_type_source_float]
    filters = @default_filters.deep_dup
    filters[:hash_with_type_source_true] = { :a => 'false' }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:hash_with_type_source_true] == filters[:hash_with_type_source_true]
    filters = @default_filters.deep_dup
    filters[:hash_with_type_source_false] = { :a => 'true' }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:hash_with_type_source_false] == filters[:hash_with_type_source_false]
    filters = @default_filters.deep_dup
    filters[:hash_with_type_source_array] = { :a => 's' }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:hash_with_type_source_array] == filters[:hash_with_type_source_array]
    filters[:hash_with_type_source_array] = { :a => 'test' }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:hash_with_type_source_array] == filters[:hash_with_type_source_array]
    filters = @default_filters.deep_dup
    filters[:hash_with_type_source_hash] = { :a => {:a => 1} }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:hash_with_type_source_hash] == filters[:hash_with_type_source_hash]
    filters[:hash_with_type_source_hash] = { :a => 2.2 }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:hash_with_type_source_hash] == filters[:hash_with_type_source_hash]
    filters = @default_filters.deep_dup
    filters[:hash_with_type_source_array_hash] = { :a => ['3'] }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:hash_with_type_source_array_hash] == filters[:hash_with_type_source_array_hash]
    filters = @default_filters.deep_dup
    filters[:hash_with_type_source_array_hash_array] = {:a => [ {:bb => ['s'] } ]}
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:hash_with_type_source_array_hash_array] == filters[:hash_with_type_source_array_hash_array]
    filters[:hash_with_type_source_array_hash_array] = {:a => [ {:bb => [1,'2'] } ]}
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:hash_with_type_source_array_hash_array] == filters[:hash_with_type_source_array_hash_array]
    filters = @default_filters.deep_dup
    filters[:hash_with_type_source_hash_hash] = { :a => { :aa => {:a => 3} } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:hash_with_type_source_hash_hash] == filters[:hash_with_type_source_hash_hash] 
    filters[:hash_with_type_source_hash_hash] = { :a => { :aa => 'test' } }
    filterd_filters = establish_filters_consistency(filters, @original_data)
    assert_not filterd_filters[:hash_with_type_source_hash_hash] == filters[:hash_with_type_source_hash_hash]
  end

end
