#!/usr/bin/env ruby
# -*- coding: utf-8 -*-

module SidfmVulnerabilitiesControllerSupport
  # 既存のメソッドとメソッド名が被らないように注意

  DAY_SECONDS = 24 * 60 * 60
  
  # ソート
  def sort_vuls_content(content:, order:, role_admin:, user_host_ids:, user_category_ids:, index:, corresp_required:, category_host_ids:, prior_category:)
    #min_created_onでソートする前のデータ取得処理
    #_vv_min_created_onでソートする
    get_min_created_on = ->(content){
      condition = if category_host_ids and category_host_ids.any? then
                    "WHERE sidfmd_host_id IN (SELECT unnest(ARRAY[#{category_host_ids.join(', ')}]))"
                  elsif !role_admin and user_host_ids.any? then
                    "WHERE sidfmd_host_id IN (SELECT unnest(ARRAY[#{user_host_ids.join(', ')}]))"
                  else
                    ''
                  end
      content = content.joins(%|
        LEFT OUTER JOIN(
          SELECT
            sidfmd_vul_view_id AS _vv_id,
            MIN(DATE_TRUNC('DAY', created_on)) AS order_vv_min_created_on
          FROM
            sidfmd_vv_scsids
          #{condition}
          GROUP BY sidfmd_vul_view_id 
        )AS order_vv_min_created_ons
        ON sidfmd_vul_views.id = order_vv_min_created_ons._vv_id
      |)
    }

    #要対応
    case order
    when 'warning_asc', 'warning_desc' then
      get_warning_values = ->(content, host_ids, idx){
        content = content.joins(%|
                    LEFT OUTER JOIN (
                      SELECT 
                        sidfmd_vul_view_id AS vul_view_id,
                        MIN(status_id) AS order_warning_target_vv_min_status_id,
                        #{idx == :sri ? "MAX(sri) AS order_warning_target_vv_max_sri" : "MAX(cvss) order_warning_target_vv_max_cvss"}
                      FROM
                        sidfmd_vv_scsids
                      WHERE
                        #{(host_ids and host_ids.any?) ? "sidfmd_host_id IN (SELECT unnest(ARRAY[#{host_ids.join(', ')}])) AND" : ''}
                        status_id IN (SELECT unnest(ARRAY[#{SidfmdIssue::STATUS_UNFINISHED.join(', ')}]))
                      GROUP BY
                        sidfmd_vul_view_id
                      HAVING
                        #{idx == :sri ? "MAX(sri) >= #{corresp_required[:sri]}" : "(MAX(cvss) IS NULL OR MAX(cvss) >= #{corresp_required[:cvss]})"}
                    ) AS order_vv_warning_values
                    ON sidfmd_vul_views.id = order_vv_warning_values.vul_view_id
                  |)
      }
      content = get_min_created_on.(content)
      if order == 'warning_asc' then
        if category_host_ids or !role_admin then
          content = get_warning_values.(content, (category_host_ids || user_host_ids), index)
                                          .order(%|
                                            CASE
                                            WHEN order_warning_target_vv_min_status_id IS NULL THEN
                                              100
                                            ELSE
                                              0
                                            END
                                          |)
                                          .order('order_vv_min_created_on')
                                          .order('LOWER(title COLLATE "C")')
                                          .order("abs(html_id)")
        else
          content = content.order("warning_#{index.to_s} DESC")
                                   .order('order_vv_min_created_on')
                                   .order('LOWER(title COLLATE "C")')
                                   .order("abs(html_id)")
        end
      else
        if category_host_ids or !role_admin then
          content = get_warning_values.(content, (category_host_ids || user_host_ids), index)
                                          .order(%|
                                            CASE 
                                            WHEN order_warning_target_vv_min_status_id IS NULL THEN
                                              0
                                            ELSE
                                              100
                                            END
                                          |)
                                          .order('order_vv_min_created_on DESC')
                                          .order('LOWER(title COLLATE "C") DESC')
                                          .order("abs(html_id) DESC")
        else
          content = content.order("warning_#{index.to_s}")
                                   .order('order_vv_min_created_on DESC')
                                   .order('LOWER(title COLLATE "C") DESC')
                                   .order("abs(html_id) DESC")
        end
      end
    when 'statuses_asc', 'statuses_desc' then
      order_by_status = ->(content, host_ids){
        content = if host_ids.any? then
                    content.joins(%|
                      LEFT OUTER JOIN(
                        SELECT
                          sidfmd_vul_view_id AS vul_view_id,
                          MIN(status_id) AS order_vv_min_status_id
                        FROM
                          sidfmd_vv_scsids
                        WHERE
                          sidfmd_host_id IN (SELECT unnest(ARRAY[#{host_ids.join(', ')}]))
                        GROUP BY sidfmd_vul_view_id
                      ) AS order_vv_min_status
                      ON sidfmd_vul_views.id = order_vv_min_status.vul_view_id
                    |).order(%| order_vv_min_status_id #{order == 'statuses_asc' ? 'ASC' : 'DESC'} |)
                    .order(%| LOWER(title COLLATE "C") #{order == 'statuses_asc' ? 'ASC' : 'DESC'} |)
                    .order("abs(html_id) #{order == 'statuses_asc' ? 'ASC' : 'DESC'}")
                  else
                    content
                  end
      }
      content = if category_host_ids or !role_admin then
                      order_by_status.(content, (category_host_ids || user_host_ids))
                    else
                      if order == 'statuses_asc' then
                        content.order(:min_status_id).order('LOWER(title COLLATE "C")').order("abs(html_id)")
                      else
                        content.order(:min_status_id => :desc).order('LOWER(title COLLATE "C") DESC').order("abs(html_id) DESC")
                      end
                    end
    when 'maxsri_asc', 'maxsri_desc' then
      order_by_sri = ->(content, filter_hosts){
        content = content.joins(%|
                    LEFT OUTER JOIN(
                      SELECT
                        sidfmd_vul_view_id AS vul_view_id,
                        MAX(sri) AS order_max_sri_value
                      FROM
                        sidfmd_vv_scsids
                      WHERE
                        #{filter_hosts}
                        status_id IN (SELECT unnest(ARRAY[#{SidfmdIssue::STATUS_UNFINISHED.join(', ')}]))
                      GROUP BY sidfmd_vul_view_id
                    ) AS order_vv_max_sri
                    ON sidfmd_vul_views.id = order_vv_max_sri.vul_view_id
                  |)
                  .order(order == 'maxsri_asc' ? 'order_max_sri_value DESC NULLS LAST' : 'order_max_sri_value ASC NULLS FIRST')
                  .order(%| order_vv_min_created_on #{order == 'maxsri_asc' ? 'DESC' : 'ASC'}|)
                  .order(%| LOWER(title COLLATE "C") #{order == 'maxsri_asc' ? 'ASC' : 'DESC'} |)
                  .order("abs(html_id) #{order == 'maxsri_asc' ? 'DESC' : 'ASC'}")
      }
      if category_host_ids then
        if category_host_ids.any? then
          content = order_by_sri.(get_min_created_on.(content), "sidfmd_host_id IN (SELECT unnest(ARRAY[#{category_host_ids.join(', ')}])) AND")
        end
      elsif role_admin then
        content = order_by_sri.(get_min_created_on.(content), '')
      elsif user_host_ids.any? then
        content = order_by_sri.(get_min_created_on.(content), "sidfmd_host_id IN (SELECT unnest(ARRAY[#{user_host_ids.join(', ')}])) AND")
      end
    when 'maxcvss_asc', 'maxcvss_desc' then
      order_by_cvss = ->(content, host_ids){
        content = content.joins(%|
                    LEFT OUTER JOIN(
                      SELECT
                        sidfmd_vul_view_id AS vul_view_id,
                        MAX(cvss) AS order_max_cvss_score
                      FROM
                        sidfmd_vv_scsids
                      #{host_ids.blank? ? '' : "WHERE sidfmd_host_id IN (SELECT unnest(ARRAY[#{host_ids.join(', ')}]))"}
                      GROUP BY sidfmd_vul_view_id
                    ) AS order_vv_max_cvss
                    ON sidfmd_vul_views.id = order_vv_max_cvss.vul_view_id
                  |).order(%| 
                      CASE
                      WHEN html_id < 0 THEN
                        100
                      ELSE
                        10
                      END
                      #{order == 'maxcvss_asc' ? 'ASC' : 'DESC'}
                  |)
                  .order(%| order_max_cvss_score #{order == 'maxcvss_asc' ? 'DESC NULLS LAST' : 'ASC NULLS FIRST'} |)
                  .order(%| abs(html_id) #{order == 'maxcvss_asc' ? 'ASC' : 'DESC'} |)
                  .order(%| order_vv_min_created_on #{order == 'maxcvss_asc' ? 'DESC' : 'ASC'} |)
                  .order(%| LOWER(title COLLATE "C") #{order == 'maxcvss_asc' ? 'ASC' : 'DESC'} |)
                  .order("abs(html_id) #{order == 'maxcvss_asc' ? 'ASC' : 'DESC'}")
      }

      if category_host_ids then
        if category_host_ids.any? then
          content = order_by_cvss.(get_min_created_on.(content), category_host_ids)
        end
      elsif role_admin then
        content = order_by_cvss.(get_min_created_on.(content), '')
      elsif user_host_ids.any? then
        content = order_by_cvss.(get_min_created_on.(content), user_host_ids)
      end
    when 'area_asc', 'area_desc' then
      content = get_min_created_on.(content).order(%|
                      CASE WHEN html_id > 0 THEN softek_area_id ELSE -100 END #{order == 'area_asc' ? 'DESC' : 'ASC'}
                    |).order(%| order_vv_min_created_on #{order == 'area_asc' ? 'DESC' : 'ASC'} |)
                    .order(%| LOWER(title COLLATE "C") #{order == 'area_asc' ? 'ASC' : 'DESC'} |)
                    .order(%| abs(html_id) #{order == 'area_asc' ? 'ASC' : 'DESC'} |)
    when 'exploitable_asc', 'exploitable_desc' then
      content = get_min_created_on.(content)
                                      .joins(%|
        LEFT OUTER JOIN(
          SELECT
            sidfmd_vul_view_id AS order_exploit_vv_id,
            MAX(cvss) AS order_exploit_max_cvss
          FROM
            sidfmd_vv_scsids
          #{(category_host_ids and category_host_ids.any?) ? "WHERE sidfmd_host_id IN (SELECT unnest(ARRAY[#{category_host_ids.join(', ')}])) AND status_id IN (SELECT unnest(ARRAY[#{SidfmdIssue::STATUS_UNFINISHED.join(', ')}]))" : (role_admin or user_host_ids.blank?) ?  '' : "WHERE sidfmd_host_id IN (SELECT unnest(ARRAY[#{user_host_ids.join(', ')}])) AND status_id IN (SELECT unnest(ARRAY[#{SidfmdIssue::STATUS_UNFINISHED.join(', ')}]))"}
          GROUP BY
            sidfmd_vul_view_id
        )AS order_exploit_max_cvsses 
        ON sidfmd_vul_views.id = order_exploit_max_cvsses.order_exploit_vv_id
      |).order(%|
        CASE WHEN order_exploit_max_cvss IS NULL THEN
          CASE WHEN html_id < 0 THEN
            1000
          ELSE
            1500
          END
        ELSE
          CASE 
          WHEN exploitable IS TRUE THEN
            100
          WHEN exploitable IS NULL THEN
            1400
          ELSE
            500
          END
        END
        #{order == 'exploitable_asc' ? 'ASC' : 'DESC'}
      |).order(%| order_vv_min_created_on #{order == 'exploitable_asc' ? 'DESC' : 'ASC'} |)
        .order(%| LOWER(title COLLATE "C") #{order == 'exploitable_asc' ? 'DESC' : 'ASC'} |)
        .order(%| abs(html_id) #{order == 'exploitable_asc' ? 'ASC' : 'DESC'} |)
    when 'elapseddays_asc', 'elapseddays_desc' then
      order_condition = if category_host_ids and category_host_ids.any? then
                          " AND sidfmd_host_id IN (SELECT unnest(ARRAY[#{category_host_ids.join(', ')}]))"
                        elsif !role_admin and user_host_ids.any? then
                          " AND sidfmd_host_id IN (SELECT unnest(ARRAY[#{user_host_ids.join(', ')}]))"
                        else
                          ''
                        end
      content = get_min_created_on.(content).joins(%|
                      LEFT OUTER JOIN(
                        SELECT
                          sidfmd_vul_view_id AS _vv_id,
                          MIN(created_on) AS vv_min_created_on_for_elapsed_days
                        FROM
                          sidfmd_vv_scsids
                        WHERE status_id IN (SELECT unnest(ARRAY[#{SidfmdIssue::STATUS_UNFINISHED.join(', ')}]))#{order_condition}
                        GROUP BY sidfmd_vul_view_id 
                      )AS vv_min_created_ons_for_elapsed_days
                      ON sidfmd_vul_views.id = vv_min_created_ons_for_elapsed_days._vv_id
                    |)
                    .order(%| vv_min_created_on_for_elapsed_days #{order == 'elapseddays_asc' ? 'ASC NULLS LAST' : 'DESC NULLS FIRST'} |)
                    .order(%| order_vv_min_created_on #{order == 'elapseddays_asc' ? 'DESC' : 'ASC'} |)
                    .order(%| LOWER(title COLLATE "C") #{order == 'elapseddays_asc' ? 'DESC' : 'ASC'} |)
                    .order(%| abs(html_id) #{order == 'elapseddays_asc' ? 'ASC' : 'DESC'} |)
    when 'title_asc', 'title_desc' then
      content = content.order(%| abs(html_id) #{order == 'title_asc' ? 'ASC' : 'DESC'} |)
                               .order(%| LOWER(title COLLATE "C") #{order == 'title_asc' ? 'ASC' : 'DESC'} |)
    when 'hostnames_asc', 'hostnames_desc' then
      hosts_filter = if category_host_ids and category_host_ids.any? then
                       "WHERE sidfmd_host_id IN (SELECT unnest(ARRAY[#{category_host_ids.join(', ')}]))"
                     elsif role_admin then
                       ''
                     else
                       if user_host_ids.any? then
                         "WHERE sidfmd_host_id IN (SELECT unnest(ARRAY[#{user_host_ids.join(', ')}]))"
                       else
                         ''
                       end
                     end
      content = content.joins(%|
        LEFT OUTER JOIN(
          SELECT 
            sidfmd_vul_view_id AS vul_view_id, 
            MIN(LOWER(display_name COLLATE "C")) AS min_name 
          FROM 
            sidfmd_vv_hosts
          #{hosts_filter}
          GROUP BY sidfmd_vul_view_id
        ) AS vv_hosts_min_name 
        ON sidfmd_vul_views.id = vv_hosts_min_name.vul_view_id
      |).order(%| min_name COLLATE "C" #{order == 'hostnames_asc' ? 'ASC' : 'DESC'} |)
        .order(%| LOWER(title COLLATE "C") #{order == 'hostnames_asc' ? 'ASC' : 'DESC'} |)
        .order(%| abs(html_id) #{order == 'hostnames_asc' ? 'ASC' : 'DESC'} |)
    when 'categories_asc', 'categories_desc' then
      #管理者権限でないか、ページ上部のカテゴリのフィルタがある場合は、表示されるホストのカテゴリで絞る
      filter_by_host_cat_ids = if (category_host_ids and category_host_ids.any?) or (!role_admin and user_host_ids.any?) then
                                 %| WHERE sidfmd_vv_hosts.sidfmd_host_id IN (SELECT unnest(ARRAY[#{(category_host_ids || user_host_ids).join(', ')}])) |
                               else
                                 ''
                               end
      if prior_category == 'custom' then
        content = get_min_created_on.(content).joins(%|
          LEFT OUTER JOIN(
            SELECT 
              sidfmd_vv_categories.sidfmd_vul_view_id AS vul_view_id,
              MIN(LOWER(sidfmd_vv_categories.name COLLATE "C")) AS custom_cat_name
            FROM
              sidfmd_vv_categories
              INNER JOIN sidfmd_vv_hosts ON sidfmd_vv_categories.sidfmd_vul_view_id = sidfmd_vv_hosts.sidfmd_vul_view_id
            #{filter_by_host_cat_ids}
            #{filter_by_host_cat_ids.size > 0 ? 'AND' : 'WHERE'} sidfmd_vv_categories.is_system IS FALSE
            #{(role_admin or user_category_ids.size == 0) ? '' : "AND sidfmd_vv_categories.sidfmd_category_id IN (SELECT unnest(ARRAY[#{user_category_ids.join(', ')}]))"}
            GROUP BY
              sidfmd_vv_categories.sidfmd_vul_view_id
          ) AS order_custom_category
          ON sidfmd_vul_views.id = order_custom_category.vul_view_id
        |).joins(%|
          LEFT OUTER JOIN(
            SELECT 
              sidfmd_vv_categories.sidfmd_vul_view_id AS vul_view_id,
              MIN(sidfmd_vv_categories.sidfmd_category_id) AS system_cat_id
            FROM
              sidfmd_vv_categories
              INNER JOIN sidfmd_vv_hosts ON sidfmd_vv_categories.sidfmd_vul_view_id = sidfmd_vv_hosts.sidfmd_vul_view_id
            #{filter_by_host_cat_ids}
            #{filter_by_host_cat_ids.size > 0 ? 'AND' : 'WHERE'} sidfmd_vv_categories.is_system IS TRUE
            GROUP BY
              sidfmd_vv_categories.sidfmd_vul_view_id
          ) AS order_system_category
          ON sidfmd_vul_views.id = order_system_category.vul_view_id
        |).order(%|
          CASE WHEN custom_cat_name IS NULL THEN
            NULL
          ELSE
            LOWER(custom_cat_name COLLATE "C")
          END
          #{order == 'categories_asc' ? 'ASC' : 'DESC'}
        |).order(%|
          CASE WHEN custom_cat_name IS NULL THEN
            system_cat_id 
          ELSE
            0
          END
          #{order == 'categories_asc' ? 'ASC' : 'DESC'}
        |).order(%| order_vv_min_created_on #{order == 'categories_asc' ? 'DESC' : 'ASC'} |)
          .order(%| LOWER(title COLLATE "C") #{order == 'categories_asc' ? 'DESC' : 'ASC'} |)
          .order(%| abs(html_id) #{order == 'categories_asc' ? 'ASC' : 'DESC'} |)
      else
        content = get_min_created_on.(content).joins(%|
          LEFT OUTER JOIN(
            SELECT 
              sidfmd_vul_view_id AS vul_view_id, 
              MIN(sidfmd_category_id) AS cat_id 
            FROM 
              sidfmd_vv_hosts INNER JOIN sidfmd_categories_hosts ON sidfmd_vv_hosts.sidfmd_host_id = sidfmd_categories_hosts.sidfmd_host_id
            #{filter_by_host_cat_ids}  
            GROUP BY sidfmd_vul_view_id
          ) AS vul_min_system_category 
          ON sidfmd_vul_views.id = vul_min_system_category.vul_view_id
        |).order(%| cat_id #{order == 'categories_asc' ? 'ASC' : 'DESC'} |)
          .order(%| order_vv_min_created_on #{order == 'categories_asc' ? 'DESC' : 'ASC'} |)
          .order(%| LOWER(title COLLATE "C") #{order == 'categories_asc' ? 'DESC' : 'ASC'} |)
          .order(%| abs(html_id) #{order == 'categories_asc' ? 'ASC' : 'DESC'} |)
      end

    when 'duedates_asc', 'duedates_desc' then
      order_by_duedate = ->(content, host_ids){
        # STATUS_FINISHEDのデータは計算に入れない
        content = content.joins(%|
                    LEFT OUTER JOIN(
                      SELECT
                        sidfmd_vul_view_id AS vul_view_id,
                        COUNT(sidfmd_host_id) AS count_unset_due_date_hosts
                      FROM 
                        sidfmd_vv_scsids
                      WHERE sidfmd_host_id IN (SELECT unnest(ARRAY[#{host_ids.join(', ')}])) 
                        AND status_id IN (SELECT unnest(ARRAY[#{SidfmdIssue::STATUS_UNFINISHED.join(', ')}]))
                        AND due_date IS NOT NULL
                      GROUP BY sidfmd_vul_view_id
                    ) AS count_unset_duedates
                    ON sidfmd_vul_views.id = count_unset_duedates.vul_view_id
                  |).joins(%|
                    LEFT OUTER JOIN(
                      SELECT
                        sidfmd_vul_view_id AS vul_view_id,
                        COUNT(sidfmd_host_id) AS count_due_date_hosts
                      FROM
                        sidfmd_vv_scsids
                      WHERE sidfmd_host_id IN (SELECT unnest(ARRAY[#{host_ids.join(', ')}]))
                        AND status_id IN (SELECT unnest(ARRAY[#{SidfmdIssue::STATUS_UNFINISHED.join(', ')}]))
                      GROUP BY sidfmd_vul_view_id
                    ) AS count_duedates
                    ON sidfmd_vul_views.id = count_duedates.vul_view_id
                  |).order(%|
                    CASE 
                    WHEN count_unset_due_date_hosts > 0 AND count_due_date_hosts > 0 THEN
                      ROUND(CAST(CAST(count_unset_due_date_hosts AS FLOAT) / CAST(count_due_date_hosts AS FLOAT) * 100.0 as numeric) , 1)
                    ELSE
                      0.0
                    END
                    #{order == 'duedates_asc' ? 'DESC' : 'ASC'}
                  |)
                  .order(%| order_vv_min_created_on #{order == 'duedates_asc' ? 'DESC' : 'ASC'} |)
                  .order(%| LOWER(title COLLATE "C") #{order == 'duedates_asc' ? 'DESC' : 'ASC'} |)
                  .order(%| abs(html_id) #{order == 'duedates_asc' ? 'ASC' : 'DESC'} |)
      }

      content = if (category_host_ids and category_host_ids.any?) or (!role_admin and user_host_ids.any?) then
                      order_by_duedate.(get_min_created_on.(content), (category_host_ids || user_host_ids))
                    elsif role_admin then
                      get_min_created_on.(content).order(%|
                        ROUND(CAST(duedates_percent as numeric), 1) #{order == 'duedates_asc' ? 'DESC' : 'ASC'}
                      |)
                      .order(%| order_vv_min_created_on #{order == 'duedates_asc' ? 'DESC' : 'ASC'} |)
                      .order(%| LOWER(title COLLATE "C") #{order == 'duedates_asc' ? 'DESC' : 'ASC'} |)
                      .order(%| abs(html_id) #{order == 'duedates_asc' ? 'ASC' : 'DESC'} |)
                    else
                      content
                    end
    when 'finished_asc', 'finished_desc' then
      order_by_fixed_percent = ->(content, host_ids){
        content = content.joins(%|
          LEFT OUTER JOIN(
            SELECT
              sidfmd_vul_view_id AS vul_view_id,
              COUNT(sidfmd_host_id) AS count_fin_host_id
            FROM 
              sidfmd_vv_scsids
            WHERE 
              status_id IN (SELECT unnest(ARRAY[#{SidfmdIssue::STATUS_FINISHED.join(', ')}]))
              AND sidfmd_host_id IN (SELECT unnest(ARRAY[#{host_ids.join(', ')}]))
            GROUP BY sidfmd_vul_view_id
          ) AS count_fin_host_ids
          ON sidfmd_vul_views.id = count_fin_host_ids.vul_view_id
        |).joins(%|
          LEFT OUTER JOIN(
            SELECT
              sidfmd_vul_view_id AS vul_view_id,
              COUNT(sidfmd_host_id) AS count_host_id
            FROM 
              sidfmd_vv_scsids
            WHERE
              sidfmd_host_id IN (SELECT unnest(ARRAY[#{host_ids.join(', ')}]))
            GROUP BY sidfmd_vul_view_id
          ) AS count_host_ids
          ON sidfmd_vul_views.id = count_host_ids.vul_view_id
        |).order(%|
          ROUND(CAST(CAST(COALESCE(count_fin_host_id, 0) AS FLOAT) / CAST(COALESCE(count_host_id, 0) AS FLOAT) * 100.0 as numeric), 1) 
          #{order == 'finished_asc' ? 'DESC' : 'ASC'}
        |)
        .order(%| order_vv_min_created_on #{order == 'finished_asc' ? 'DESC' : 'ASC'} |)
        .order(%| LOWER(title COLLATE "C") #{order == 'finished_asc' ? 'DESC' : 'ASC'} |)
        .order(%| abs(html_id) #{order == 'finished_asc' ? 'ASC' : 'DESC'} |)
      }

      content = if (category_host_ids and category_host_ids.any?) or (!role_admin and user_host_ids.any?) then
                      order_by_fixed_percent.(get_min_created_on.(content), (category_host_ids || user_host_ids))
                    elsif role_admin then
                      get_min_created_on.(content)
                                        .order("ROUND(CAST(fixed_percent as numeric), 1) #{order == 'finished_asc' ? 'DESC' : 'ASC'}")
                                        .order(%| order_vv_min_created_on #{order == 'finished_asc' ? 'DESC' : 'ASC'} |)
                                        .order(%| LOWER(title COLLATE "C") #{order == 'finished_asc' ? 'DESC' : 'ASC'} |)
                                        .order(%| abs(html_id) #{order == 'finished_asc' ? 'ASC' : 'DESC'} |)
                    else
                      content
                    end
    end

    content 
  end

  # フィルタの初期値
  def default_vuls_filters
    filters = {}
    filters[:warning] = { :values => [ 'warning', 'others', 'all' ].map(&:freeze).freeze, :default => 'all'.freeze }
    filters[:status] = {
      :values => (SidfmdIssue::STATUS_ALL.collect {|x| x.to_s } +
                  [ SidfmdIssue::STATUS_UNFINISHED.collect {|x| x.to_s }.join(':') ] +
                  [ SidfmdIssue::STATUS_FINISHED.collect {|x| x.to_s }.join(':') ] +
                  [ '0' ]).map(&:freeze).freeze, :default => '0'.freeze }
    filters[:sris] = {
      :values => SidfmdIssueSri::VALUES.map{|v| [v.to_s, v]}.to_h,
      :default => [].freeze
    }
    filters[:cvsses] = {
      :values => SidfmdIssueCve::DISPLAY_SORTED_LABELS.map{|v| [v.to_s, v]}.to_h,
      :default => [].freeze
    }
    filters[:area] = { :values => (SidfmdArea::VALUES.collect {|x| x.to_s } + [ '' ]).map(&:freeze).freeze, :default => ''.freeze }
    filters[:exploitable] = { :values => [ 'true', '' ].map(&:freeze).freeze, :default => ''.freeze }
    filters[:categories] = {
      :type_source => { #type_sourceはdefaultでは型が不明な場合に使う。各値には期待されるデータと同じ型のデータを入れる
        :ids => [0].freeze,
        :is_and => false,
        :is_except => false
      },
      :values => nil,
      :default => {
        :ids => [].freeze,
        :is_and => false,
        :is_except => false
      }
    }
    filters[:due_date] = { :values => nil, :default => '::' }
    filters[:keyword] = { :values => nil, :default => '' }
    filters[:date] = {
      :values => nil,
      :default => {
        :detected_date => '::',
        :created_date => '::',
        :updated_date => '::',
      }
    }
    filters[:products] = {
      :type_source => {
        :product_ids => [0],
        :version_ids => [0],
        :lproduct_ids => [0],
        :lversion_ids => [0]
      },
      :values => nil,
      :default => {
        :product_ids => [],
        :version_ids => [],
        :lproduct_ids => [],
        :lversion_ids => []
      }
    }
    filters[:cvss_vector] = {
      :type_source => {
        :cvss_v2 => SidfmdIssueCve.get_cvss_v2_vectors.map{|vector, value| [ vector.to_sym, value['values'].keys.first.to_s ] }.to_h,
        :cvss_v3 => SidfmdIssueCve.get_cvss_v3_vectors.map{|vector, value| [ vector.to_sym, value['values'].keys.first.to_s ] }.to_h,
        :is_target_unregistered => false,
      },
      :values => nil,
      :default => {
        :cvss_v2 => SidfmdIssueCve.get_cvss_v2_vectors.keys.map{|vector| [ vector.to_sym, nil ] }.to_h,
        :cvss_v3 => SidfmdIssueCve.get_cvss_v3_vectors.keys.map{|vector| [ vector.to_sym, nil ] }.to_h,
        :is_target_unregistered => false,
      }
    }
    filters[:ctags] = {
      :values => nil,
      :type_source => {
        :ids => [0]
      },
      :default => { :ids => [] }
    }
    filters
  end

  # フィルタ適用
  def filter_vuls_content(content:, filters:, role_admin:, user_category_ids:, user_host_ids:, category_host_ids:, index:, corresp_required:)
    #プロダクト検索
    if filters[:products].values.select{|v| v.size > 0 }.any? then
      prod_info = filters[:products].symbolize_keys
      issue_html_ids = []
      if prod_info[:product_ids] and prod_info[:product_ids].any? then
        #productが検索対象
        issues = SidfmdIssue.where(
          "id IN (?) OR id IN (?)",
          SidfmdIssueAffprod.where(:product_id => prod_info[:product_ids]).select(:sidfmd_issue_id),
          SidfmdIssueAffver.where(:product_id => prod_info[:product_ids]).select(:sidfmd_issue_id)
        )
        unless role_admin then
          issues = issues.where(:sidfmd_host_id => user_host_ids)
        end
        issue_html_ids |= issues.pluck(:html_id)
      end
      if prod_info[:version_ids] and prod_info[:version_ids].any? then
        #versionが検索対象
        issues = SidfmdIssue.where(
          :id => SidfmdIssueAffver.where(:product_version_id => prod_info[:version_ids]).pluck(:sidfmd_issue_id)
        )
        unless role_admin then
          issues = issues.where(:sidfmd_host_id => user_host_ids)
        end
        issue_html_ids |= issues.pluck(:html_id)
      end
      if prod_info[:lproduct_ids] and prod_info[:lproduct_ids].any? then
        #lproductが検索対象
        vuls = SidfmdLocalVul.joins(:sidfmd_local_vul_lapps)
                             .joins('LEFT OUTER JOIN sidfmd_issues ON sidfmd_issues.html_id = sidfmd_local_vuls.html_id')
                             .where('sidfmd_local_vul_lapps.sidfmd_lproduct_id IN (?)', prod_info[:lproduct_ids])
                             .select('sidfmd_issues.html_id AS html_id')
        unless role_admin then
          vuls = vuls.where(:sidfmd_issues => { :sidfmd_host_id => user_host_ids })
        end
        issue_html_ids |= vuls.pluck(:html_id)
      end
      if prod_info[:lversion_ids] and prod_info[:lversion_ids].any? then
        #lversionが検索対象
        vuls = SidfmdLocalVul.joins(:sidfmd_local_vul_lapps)
                             .joins('LEFT OUTER JOIN sidfmd_issues ON sidfmd_issues.html_id = sidfmd_local_vuls.html_id')
                             .where('sidfmd_local_vul_lapps.sidfmd_lversion_id IN (?)', prod_info[:lversion_ids])
                             .select('sidfmd_issues.html_id AS html_id')
        unless role_admin then
          vuls = vuls.where(:sidfmd_issues => { :sidfmd_host_id => user_host_ids })
        end
        issue_html_ids |= vuls.pluck(:html_id)
      end

      if issue_html_ids.any? then
        content = content.where(:html_id => issue_html_ids)
      else
        content = content.where(:html_id => 0)
      end
    end

    # 要注意
    if filters[:warning] == 'warning' || filters[:warning] == 'others' then
      if category_host_ids or user_host_ids then
        #SidfmdIssue#update_value_by_scsidsの処理に合わせる
        filter_by_warning_sri = ->(content){
          if filters[:warning] == 'warning' then
            content.where(
              :id => SidfmdVvScsid.where(
                       :sidfmd_vul_view_id => content.select(:id),
                       :sidfmd_host_id => (category_host_ids || user_host_ids)
                     ).group(:sidfmd_vul_view_id)
                      .having("MIN(status_id) IN (?)", SidfmdIssue::STATUS_UNFINISHED)
                      .select(:sidfmd_vul_view_id)
            ).where(
              :id => SidfmdVvScsid.where(
                       :sidfmd_vul_view_id => content.select(:id),
                       :sidfmd_host_id => (category_host_ids || user_host_ids),
                       :status_id => SidfmdIssue::STATUS_UNFINISHED
                     ).group(:sidfmd_vul_view_id)
                      .having("MAX(sri) >= ?", corresp_required[:sri])
                      .select(:sidfmd_vul_view_id)
            )
          else
            content.where(%|
             NOT id IN (?) OR NOT id IN (?)  
            | , SidfmdVvScsid.where(
                 :sidfmd_vul_view_id => content.select(:id),
                 :sidfmd_host_id => (category_host_ids || user_host_ids)
               ).group(:sidfmd_vul_view_id)
                .having("MIN(status_id) IN (?)", SidfmdIssue::STATUS_UNFINISHED)
                .select(:sidfmd_vul_view_id),
               SidfmdVvScsid.where(
                 :sidfmd_vul_view_id => content.select(:id),
                 :sidfmd_host_id => (category_host_ids || user_host_ids),
                 :status_id => SidfmdIssue::STATUS_UNFINISHED
               ).group(:sidfmd_vul_view_id)
                .having("MAX(sri) >= ?", corresp_required[:sri])
                .select(:sidfmd_vul_view_id)
            )
          end
        }

        filter_by_warning_cvss = ->(content){
          content.where("id #{filters[:warning] == 'warning' ? '' : 'NOT'} IN (?)",
            SidfmdVvScsid.where(:sidfmd_host_id => (category_host_ids || user_host_ids))
                         .group(:sidfmd_vul_view_id)
                         .having(%|
                           MIN(status_id) IN (?) AND 
                           #{index == :sri ? "MAX(sri) >= #{corresp_required[:sri]}" : "(MAX(cvss) IS NULL OR MAX(cvss) >= #{corresp_required[:cvss]})"}
                         |, SidfmdIssue::STATUS_UNFINISHED)
                         .select(:sidfmd_vul_view_id)
         )
        }
        content = if index == :sri then
                        filter_by_warning_sri.(content)
                      else
                        filter_by_warning_cvss.(content)
                      end
      else
        if filters[:warning] == 'warning' then
          content = index == :sri ? content.where(:warning_sri => true) : content.where(:warning_cvss => true)
        else
          content = index == :sri ? content.where.not(:warning_sri => true) : content.where.not(:warning_cvss => true)
        end
      end

    end

    # 対応状況
    # min_status_idで判断
    if filters[:status] != '0' then
      filter_by_status = ->(content, host_ids, status_ids){
        content = if host_ids.any? then
                    content.joins(%|
                      LEFT OUTER JOIN(
                        SELECT
                          sidfmd_vul_view_id AS vul_view_id,
                          MIN(status_id) AS vv_min_status_id
                        FROM
                          sidfmd_vv_scsids
                        WHERE sidfmd_host_id IN (SELECT unnest(ARRAY[#{host_ids.join(', ')}]))
                        GROUP BY sidfmd_vul_view_id
                      ) AS vv_min_status
                      ON sidfmd_vul_views.id = vv_min_status.vul_view_id
                    |).where('vv_min_status_id IN (?)', status_ids)
                  else
                    content.where(:id => 0)
                  end
      }

      if /\A(\d):(\d)\z/ =~ filters[:status] then
        status1 = Regexp.last_match(1).to_i
        status2 = Regexp.last_match(2).to_i
        if category_host_ids then
          content = filter_by_status.(content, category_host_ids, [ status1, status2 ])
        else
          content = if role_admin then
                          content.where(:min_status_id => [ status1, status2 ])
                        else
                          filter_by_status.(content, user_host_ids, [ status1, status2 ])
                        end
        end
      else
        if category_host_ids then
          content = filter_by_status.(content, category_host_ids, [ filters[:status] ])
        else
          content = if role_admin then
                          content.where(:min_status_id => filters[:status])
                        else
                          filter_by_status.(content, user_host_ids, [ filters[:status] ])
                        end
        end
      end
    end

    # 最大SRI
    if filters[:sris].any? then
      filters[:sris] = filters[:sris].map(&:to_i)
      filter_by_sri = ->(content, filter_hosts){
        content = if filters[:sris].include?(SidfmdIssueSri::VALUE_NONE) then
                    content.joins(%|
                      LEFT OUTER JOIN(
                        SELECT
                          sidfmd_vul_view_id AS vul_view_id,
                          MAX(sri) AS max_sri_value
                        FROM
                          sidfmd_vv_scsids
                        WHERE 
                          #{filter_hosts}
                          status_id IN (SELECT unnest(ARRAY[#{SidfmdIssue::STATUS_UNFINISHED.join(', ')}]))
                        GROUP BY sidfmd_vul_view_id           
                      ) AS vv_max_sri
                      ON sidfmd_vul_views.id = vv_max_sri.vul_view_id 
                    |).joins(%|
                      LEFT OUTER JOIN(
                        SELECT DISTINCT
                          sidfmd_vul_view_id AS vul_view_id2
                        FROM
                          sidfmd_vv_scsids 
                        WHERE
                          #{filter_hosts}
                          status_id IN (SELECT unnest(ARRAY[#{SidfmdIssue::STATUS_UNFINISHED.join(', ')}]))
                        GROUP BY sidfmd_vul_view_id 
                      ) AS vv_scsids 
                      ON sidfmd_vul_views.id = vv_scsids.vul_view_id2
                    |)
                    .where('max_sri_value IN (?) OR vul_view_id2 IS NULL', filters[:sris])
                  else
                    content.joins(%|
                      LEFT OUTER JOIN(
                        SELECT
                          sidfmd_vul_view_id AS vul_view_id,
                          MAX(sri) AS max_sri_value
                        FROM
                          sidfmd_vv_scsids
                        WHERE 
                          #{filter_hosts}
                          status_id IN (SELECT unnest(ARRAY[#{SidfmdIssue::STATUS_UNFINISHED.join(', ')}]))
                        GROUP BY sidfmd_vul_view_id           
                      ) AS vv_max_sri
                      ON sidfmd_vul_views.id = vv_max_sri.vul_view_id 
                    |).where('max_sri_value IN (?)',filters[:sris])
                  end
      }
      if category_host_ids then
        if category_host_ids.any? then
          content = filter_by_sri.(content, "sidfmd_host_id IN (SELECT unnest(ARRAY[#{category_host_ids.join(', ')}])) AND")
        end
      elsif role_admin || user_host_ids.any? then
        content = filter_by_sri.(content, (role_admin ? '' : "sidfmd_host_id IN (SELECT unnest(ARRAY[#{user_host_ids.join(', ')}])) AND"))
      else
        content = content.where(:id => 0)
      end
    end

    # 最大CVSS
    if filters[:cvsses].any? then
      label_values = {
        :notreg => nil,
        :d4 => { :top => 10.0 , :bottom => 9.0 },
        :d3 => { :top => 8.9, :bottom => 7.0 },
        :d2 => { :top => 6.9, :bottom => 4.0 },
        :d1 => { :top => 3.9, :bottom => 0.0 },
      }
      conds = []
      filters[:cvsses].each do |label|
        values = label_values[label.to_sym]
        if values then
          conds << "vv_max_cvss_score >= #{values[:bottom]} AND vv_max_cvss_score <= #{values[:top]}"
        else
          conds << "vv_max_cvss_score IS NULL"
        end
      end
      condition = conds.join(' OR ')

      filter_by_cvss = ->(content, condition, filter_hosts){
        content = content.joins(%|
                    LEFT OUTER JOIN(
                      SELECT
                        sidfmd_vul_view_id AS vul_view_id,
                        MAX(cvss) AS vv_max_cvss_score
                      FROM
                        sidfmd_vv_scsids
                      #{filter_hosts}
                      GROUP BY sidfmd_vul_view_id
                    ) AS vv_max_cvss
                    ON sidfmd_vul_views.id = vv_max_cvss.vul_view_id
                  |).where(condition)
      }
      if category_host_ids then
        if category_host_ids.any? then
          content = filter_by_cvss.(content, condition, "WHERE sidfmd_host_id IN (SELECT unnest(ARRAY[#{category_host_ids.join(', ')}]))")
        end
      elsif role_admin or user_host_ids.any? then
        content = filter_by_cvss.(content, condition, (role_admin ? '' : "WHERE sidfmd_host_id IN (SELECT unnest(ARRAY[#{user_host_ids.join(', ')}]))"))
      else
        content = content.where(:id => 0)
      end
    end

    #CVSS指標
    if filters[:cvss_vector].size > 0 then
      condition = ''
      if filters[:cvss_vector][:is_target_unregistered].to_s == 'true' then
        condition = %|
          c2_av IS NULL AND
          c2_ac IS NULL AND
          c2_au IS NULL AND
          c2_c IS NULL AND
          c2_i IS NULL AND
          c2_a IS NULL AND
          c3_av IS NULL AND
          c3_ac IS NULL AND
          c3_pr IS NULL AND
          c3_ui IS NULL AND
          c3_s IS NULL AND
          c3_c IS NULL AND
          c3_i IS NULL AND
          c3_a IS NULL
        |
      elsif filters[:cvss_vector][:cvss_v2].values.select{|v| v != nil }.any? or filters[:cvss_vector][:cvss_v3].values.select{|v| v != nil }.any? then
        cvss_filter_items = []
        filters[:cvss_vector][:cvss_v2].each do |vector, value|
          if value then
            cvss_filter_items << "c2_#{vector.to_s.downcase} = '#{value}'"
          end
        end
        filters[:cvss_vector][:cvss_v3].each do |vector, value|
          if value then
            cvss_filter_items << "c3_#{vector.to_s.downcase} = '#{value}'"
          end
        end
        condition = cvss_filter_items.join(' AND ')
      end
      if condition.size > 0 then
        content = content.where(%|
          id IN (
            SELECT sidfmd_vul_view_id 
            FROM sidfmd_vv_cves AS cve_table
            WHERE( 
              #{condition} AND
              id = (
                  SELECT id
                  FROM sidfmd_vv_cves AS cve_table2
                  WHERE cve_table.sidfmd_vul_view_id = cve_table2.sidfmd_vul_view_id AND cve_table.cve_id = cve_table2.cve_id
                  ORDER BY 
                  CASE
                  WHEN c3_update_datetime IS NOT NULL THEN
                    100
                  WHEN c2_update_datetime IS NOT NULL THEN
                    200
                  ELSE
                    300
                  END,
                  c3_update_datetime DESC,
                  c2_update_datetime DESC,
                  id DESC
                  LIMIT 1
              )
            )
          )
        |)
      end
    end

    # SofTek影響範囲
    if filters[:area] != '' then
      content = content.where(:softek_area_id => filters[:area])
    end

    # 攻撃コード
    if filters[:exploitable].to_s == 'true' then
      #CVSSが未定義の場合は、表示が---になるので該当させない。(元々のTSV出力での表示方法と同じ)
      if category_host_ids or !role_admin then
        content = content.where(
          :id => SidfmdVvScsid.where(:status_id => SidfmdIssue::STATUS_UNFINISHED)
                              .where(:sidfmd_host_id => (category_host_ids || user_host_ids))
                              .where.not(:cvss => nil)
                              .select(:sidfmd_vul_view_id)
        ).where(:exploitable => true)
      else
        content = content.where(:exploitable => true)
                                 .where.not(:cvss_label => 'notreg')
      end
    end

    #カテゴリ(複数)
    if filters[:categories][:ids].any? then
      unless role_admin then
        filters[:categories][:ids] = (filters[:categories][:ids].map(&:to_i) & user_category_ids) + SidfmdCategory.where(:is_system => true).where(:id => filters[:categories][:ids]).pluck(:id)
      end
      if category_host_ids or !role_admin then
        #管理者権限でないかページ上部のカテゴリのフィルタがある場合は、カテゴリを対象のホストのカテゴリに絞り込む
        if filters[:categories][:is_except].to_s == 'true' then
          content = content.where.not(
            :id => SidfmdVvHost.joins(
                     'LEFT OUTER JOIN sidfmd_categories_hosts ON sidfmd_categories_hosts.sidfmd_host_id = sidfmd_vv_hosts.sidfmd_host_id'
                   )
                   .where(:sidfmd_vv_hosts => { :sidfmd_host_id => (category_host_ids || user_host_ids)})
                   .where('sidfmd_categories_hosts.sidfmd_category_id IN (?)', filters[:categories][:ids])
                   .distinct
                   .select(:sidfmd_vul_view_id)
          )
        else
          content = content.where(
            :id => if filters[:categories][:is_and].to_s == 'true' then
                     SidfmdVvHost.joins(
                       'LEFT OUTER JOIN sidfmd_categories_hosts ON sidfmd_categories_hosts.sidfmd_host_id = sidfmd_vv_hosts.sidfmd_host_id'
                     )
                     .where(:sidfmd_vv_hosts => { :sidfmd_host_id => (category_host_ids || user_host_ids)})
                     .group(:sidfmd_vul_view_id)
                     .having('ARRAY_AGG(DISTINCT sidfmd_category_id) @> ARRAY[?]', filters[:categories][:ids])
                     .distinct
                     .select(:sidfmd_vul_view_id)
                   else
                     SidfmdVvHost.joins(
                       'LEFT OUTER JOIN sidfmd_categories_hosts ON sidfmd_categories_hosts.sidfmd_host_id = sidfmd_vv_hosts.sidfmd_host_id'
                     )
                     .where(:sidfmd_vv_hosts => { :sidfmd_host_id => (category_host_ids || user_host_ids)})
                     .where('sidfmd_categories_hosts.sidfmd_category_id IN (?)', filters[:categories][:ids])
                     .distinct
                     .select(:sidfmd_vul_view_id)
                   end
          )
        end
      else
        if filters[:categories][:is_except].to_s == 'true' then
          content = content.where.not(
            :id => SidfmdVvCategory.where(:sidfmd_category_id => filters[:categories][:ids])
                                   .distinct
                                   .select(:sidfmd_vul_view_id)
          )
        else
          content = content.where(
            :id => if filters[:categories][:is_and].to_s == 'true' then
                     SidfmdVvCategory.group(:sidfmd_vul_view_id)
                                     .having('ARRAY_AGG(DISTINCT sidfmd_category_id) @> ARRAY[?]', filters[:categories][:ids])
                                     .distinct
                                     .select(:sidfmd_vul_view_id)
                   else
                     SidfmdVvCategory.where(:sidfmd_category_id => filters[:categories][:ids])
                                     .distinct
                                     .select(:sidfmd_vul_view_id)
                   end
          )
        end
      end
    end

    # 対策予定日設定済
    if filters[:due_date] != '::' then
      if /\A(|notset):(|\d{4}\/\d{2}\/\d{2}):(|\d{4}\/\d{2}\/\d{2})\z/ =~ filters[:due_date] then
        notset = ('notset' == Regexp.last_match(1))
        begindate = Regexp.last_match(2)
        enddate = Regexp.last_match(3)
        if notset then
          if category_host_ids then
            content = content.where(
              :id => SidfmdVvScsid.where(:due_date => nil).where(:sidfmd_host_id => category_host_ids).select(:sidfmd_vul_view_id)
            )
          else
            if role_admin then
              content = content.where(
                :id => SidfmdVvScsid.where(:due_date => nil).select(:sidfmd_vul_view_id)
              )
            else
              content = content.where(
                :id => SidfmdVvScsid.where(:due_date => nil).where(:sidfmd_host_id => user_host_ids).select(:sidfmd_vul_view_id)
              )
            end
          end
        else
          begin
            if begindate.to_s.size > 0 then
              begindate = Date.parse(begindate)
            else
              begindate = nil
            end
          rescue Exception => e
            log_exception(e)
            begindate = nil
          end

          begin
            if enddate.to_s.size > 0 then
              enddate = Date.parse(enddate)
            else
              enddate = nil
            end
          rescue Exception => e
            log_exception(e)
            enddate = nil
          end

          if begindate and enddate then
            if category_host_ids then
               content = content.where(
                 :id => SidfmdVvScsid.where(:due_date => begindate..enddate).where(:sidfmd_host_id => category_host_ids).select(:sidfmd_vul_view_id)
               )
            else
              if role_admin then
                content = content.where(
                  :id => SidfmdVvScsid.where(:due_date => begindate..enddate).select(:sidfmd_vul_view_id)
                )
              else
                content = content.where(
                  :id => SidfmdVvScsid.where(:due_date => begindate..enddate).where(:sidfmd_host_id => user_host_ids).select(:sidfmd_vul_view_id)
                )
              end
            end
          elsif begindate then
            if category_host_ids then
              content = content.where(
                :id => SidfmdVvScsid.where('due_date >= ?', begindate).where(:sidfmd_host_id => category_host_ids).select(:sidfmd_vul_view_id)
              )
            else
              if role_admin then
                content = content.where(
                  :id => SidfmdVvScsid.where('due_date >= ?', begindate).select(:sidfmd_vul_view_id)
                )
              else
                content = content.where(
                  :id => SidfmdVvScsid.where('due_date >= ?', begindate).where(:sidfmd_host_id => user_host_ids).select(:sidfmd_vul_view_id)
                )
              end
            end
          elsif enddate then
            if category_host_ids then
              content = content.where(
                :id => SidfmdVvScsid.where('due_date <= ?', enddate).where(:sidfmd_host_id => category_host_ids).select(:sidfmd_vul_view_id)
              )
            else
              if role_admin then
                content = content.where(
                  :id => SidfmdVvScsid.where('due_date <= ?', enddate).select(:sidfmd_vul_view_id)
                )
              else
                content = content.where(
                  :id => SidfmdVvScsid.where('due_date <= ?', enddate).where(:sidfmd_host_id => user_host_ids).select(:sidfmd_vul_view_id)
                )
              end
            end
          end
        end
      end
    end

    # キーワード検索
    if filters[:keyword].size > 0 then
      kwd = filters[:keyword].gsub('/', '')
      if kwd.size > 0 then
        if /\A\s*(\d+)\s*\z/ =~ kwd then
          html_id = Regexp.last_match(1)
          content = content.where(%|
            html_id = ? OR 
            title ILIKE ? OR 
            id IN (SELECT sidfmd_vul_view_id FROM sidfmd_vv_cves WHERE cve_id ILIKE ?)
          |, html_id.to_i, "%#{ActiveRecord::Base.send(:sanitize_sql_like, html_id.to_s.strip)}%", "%#{ActiveRecord::Base.send(:sanitize_sql_like, kwd.strip)}%")
        elsif /\A\s*KB(\d+)\s*\z/i =~ kwd then
          kbid = -Regexp.last_match(1).to_i
          content = content.where(
            'html_id = ? OR title ILIKE ?', kbid.to_i, "%#{ActiveRecord::Base.send(:sanitize_sql_like, kwd.strip)}%"
          )
        else
          content = content.where(%|
            id IN (SELECT sidfmd_vul_view_id FROM sidfmd_vv_cves WHERE cve_id ILIKE ?) OR 
            title ILIKE ?
          |, "%#{ActiveRecord::Base.send(:sanitize_sql_like, kwd.strip)}%", "%#{ActiveRecord::Base.send(:sanitize_sql_like, kwd.strip)}%")
        end
      else
        #/で検索すると、/でtitleが連結されているため、該当してしまう可能性がある
        #/は無効な文字として該当させない
        content = content.where(:title => '')
      end
    end

    # 日付指定検索
    filters_date_searching_item = filters[:date].select{|k, v| v != '::'}.keys.first
    if filters_date_searching_item then
      if /^(in|rev):(\d{4}\/\d{2}\/\d{2}|):(\d{4}\/\d{2}\/\d{2}|)$/ =~ filters[:date][filters_date_searching_item] then
        orig_flg_rev = Regexp.last_match(1)
        orig_begin_date = Regexp.last_match(2)
        orig_end_date = Regexp.last_match(3)
        if orig_flg_rev.size > 0 and orig_begin_date.size == 0 and orig_end_date.size == 0 then
          filters[:date][filters_date_searching_item] = '::'
        else
          flg_rev = orig_flg_rev == 'rev' ? true : false
          begin_date = orig_begin_date.size > 0 ? Date.strptime(orig_begin_date, '%Y/%m/%d') : nil
          end_date = orig_end_date.size > 0 ? Date.strptime(orig_end_date, '%Y/%m/%d') : nil

          if flg_rev then
            if begin_date and end_date then
              begin_date = begin_date.to_time
              end_date = end_date.to_time + DAY_SECONDS - 1
              case filters_date_searching_item
              when :detected_date then
                if category_host_ids then
                  content = content.where.not(
                    :id => SidfmdVvScsid.where(:sidfmd_host_id => category_host_ids)
                                        .group(:sidfmd_vul_view_id)
                                        .having('MIN(created_on) BETWEEN ? AND ?', begin_date, end_date)
                                        .select(:sidfmd_vul_view_id)
                  )
                else
                  if role_admin then
                    content = content.where.not(:min_created_on => begin_date..end_date)
                  else
                    content = content.where.not(
                      :id => SidfmdVvScsid.where(:sidfmd_host_id => user_host_ids)
                                          .group(:sidfmd_vul_view_id)
                                          .having('MIN(created_on) BETWEEN ? AND ?', begin_date, end_date)
                                          .select(:sidfmd_vul_view_id)
                    )
                  end
                end
              when :created_date then
                content = content.where.not(
                  :html_id => SidfmdHtmlidDate.where('create_datetime BETWEEN ? AND ?', begin_date, end_date).select(:htmlid)
                )
              when :updated_date then
                content = content.where.not(
                  :html_id => SidfmdHtmlidDate.where('update_datetime BETWEEN ? AND ?', begin_date, end_date).select(:htmlid)
                )
              end
            elsif begin_date then
              begin_date = begin_date.to_time
              case filters_date_searching_item
              when :detected_date then
                if category_host_ids then
                  content = content.where.not(
                    :id => SidfmdVvScsid.where(:sidfmd_host_id => category_host_ids)
                                        .group(:sidfmd_vul_view_id)
                                        .having('MIN(created_on) >= ?', begin_date)
                                        .select(:sidfmd_vul_view_id)
                  )
                else
                  if role_admin then
                    content = content.where.not('min_created_on >= ?', begin_date)
                  else
                    content = content.where.not(
                      :id => SidfmdVvScsid.where(:sidfmd_host_id => user_host_ids)
                                          .group(:sidfmd_vul_view_id)
                                          .having('MIN(created_on) >= ?', begin_date)
                                          .select(:sidfmd_vul_view_id)
                    )
                  end
                end
              when :created_date then
                content = content.where.not(
                  :html_id => SidfmdHtmlidDate.where('create_datetime >= ?', begin_date).select(:htmlid)
                )
              when :updated_date then
                content = content.where.not(
                  :html_id => SidfmdHtmlidDate.where('update_datetime >= ?', begin_date).select(:htmlid)
                )
              end
            elsif end_date then
              end_date = end_date.to_time + DAY_SECONDS - 1
              case filters_date_searching_item
              when :detected_date then
                if category_host_ids then
                  content = content.where.not(
                    :id => SidfmdVvScsid.where(:sidfmd_host_id => category_host_ids)
                                        .group(:sidfmd_vul_view_id)
                                        .having('MIN(created_on) <= ?', end_date)
                                        .select(:sidfmd_vul_view_id)
                  )
                else
                  if role_admin then
                    content = content.where.not('min_created_on <= ?', end_date)
                  else
                    content = content.where.not(
                      :id => SidfmdVvScsid.where(:sidfmd_host_id => user_host_ids)
                                          .group(:sidfmd_vul_view_id)
                                          .having('MIN(created_on) <= ?', end_date)
                                          .select(:sidfmd_vul_view_id)
                    )
                  end
                end
              when :created_date then
                content = content.where.not(
                  :html_id => SidfmdHtmlidDate.where('create_datetime <= ?', end_date).select(:htmlid)
                )
              when :updated_date then
                content = content.where.not(
                  :html_id => SidfmdHtmlidDate.where('update_datetime <= ?', end_date).select(:htmlid)
                )
              end
            else
              # last resort
              filters[:date][filters_date_searching_item] = '::'
            end
          else
            if begin_date and end_date then
              begin_date = begin_date.to_time
              end_date = end_date.to_time + DAY_SECONDS - 1
              case filters_date_searching_item
              when :detected_date then
                if category_host_ids then
                  content = content.where(
                    :id => SidfmdVvScsid.where(:sidfmd_host_id => category_host_ids)
                                        .group(:sidfmd_vul_view_id)
                                        .having('MIN(created_on) BETWEEN ? AND ?', begin_date, end_date)
                                        .select(:sidfmd_vul_view_id)
                  )
                else
                  if role_admin then
                    content = content.where(:min_created_on => begin_date..end_date)
                  else
                    content = content.where(
                      :id => SidfmdVvScsid.where(:sidfmd_host_id => user_host_ids)
                                          .group(:sidfmd_vul_view_id)
                                          .having('MIN(created_on) BETWEEN ? AND ?', begin_date, end_date)
                                          .select(:sidfmd_vul_view_id)
                    )
                  end
                end
              when :created_date then
                content = content.where(
                  :html_id => SidfmdHtmlidDate.where('create_datetime BETWEEN ? AND ?', begin_date, end_date).select(:htmlid)
                )
              when :updated_date then
                content = content.where(
                  :html_id => SidfmdHtmlidDate.where('update_datetime BETWEEN ? AND ?', begin_date, end_date).select(:htmlid)
                )
              end
            elsif begin_date then
              begin_date = begin_date.to_time
              case filters_date_searching_item
              when :detected_date then
                if category_host_ids then
                  content = content.where(
                    :id => SidfmdVvScsid.where(:sidfmd_host_id => category_host_ids)
                                        .group(:sidfmd_vul_view_id)
                                        .having('MIN(created_on) >= ?', begin_date)
                                        .select(:sidfmd_vul_view_id)
                  )
                else
                  if role_admin then
                    content = content.where('min_created_on >= ?', begin_date)
                  else
                    content = content.where(
                      :id => SidfmdVvScsid.where(:sidfmd_host_id => user_host_ids)
                                          .group(:sidfmd_vul_view_id)
                                          .having('MIN(created_on) >= ?', begin_date)
                                          .select(:sidfmd_vul_view_id)
                    )
                  end
                end
              when :created_date then
                content = content.where(
                  :html_id => SidfmdHtmlidDate.where('create_datetime >= ?', begin_date).select(:htmlid)
                )
              when :updated_date then
                content = content.where(
                  :html_id => SidfmdHtmlidDate.where('update_datetime >= ?', begin_date).select(:htmlid)
                )
              end
            elsif end_date then
              end_date = end_date.to_time + DAY_SECONDS - 1
              case filters_date_searching_item
              when :detected_date then
                if category_host_ids then
                  content = content.where(
                    :id => SidfmdVvScsid.where(:sidfmd_host_id => category_host_ids)
                                        .group(:sidfmd_vul_view_id)
                                        .having('MIN(created_on) <= ?', end_date)
                                        .select(:sidfmd_vul_view_id)
                  )
                else
                  if role_admin then
                    content = content.where('min_created_on <= ?', end_date)
                  else
                    content = content.where(
                      :id => SidfmdVvScsid.where(:sidfmd_host_id => user_host_ids)
                                          .group(:sidfmd_vul_view_id)
                                          .having('MIN(created_on) <= ?', end_date)
                                          .select(:sidfmd_vul_view_id)
                    )
                  end
                end
              when :created_date then
                content = content.where(
                  :html_id => SidfmdHtmlidDate.where('create_datetime <= ?', end_date).select(:htmlid)
                )
              when :updated_date then
                content = content.where(
                  :html_id => SidfmdHtmlidDate.where('update_datetime <= ?', end_date).select(:htmlid)
                )
              end
            else
              # last resort
              filters[:date][filters_date_searching_item] = '::'
            end
          end
        end
      else
        filters[:date][filters_date_searching_item] = '::'
      end
    end

    #カスタムタグ検索
    if filters[:ctags] && filters[:ctags][:ids] && filters[:ctags][:ids].any? then
      unless role_admin then
        filters[:ctags][:ids] = filters[:ctags][:ids] & SidfmdCtag.user_relatable_ctag_ids(role_admin, user_category_ids)
      end
      content = content.where(
        :id => SidfmdVvCtag.where(:sidfmd_ctag_id => filters[:ctags][:ids]).select(:sidfmd_vul_view_id)
      )
    end
    content
  end

end
